# ACT I

### SCENE I. An apartment in the DUKE'S palace.

_Enter DUKE VINCENTIO, ESCALUS, Lords and Attendants_

**DUKE VINCENTIO**  
Escalus.  

**ESCALUS**  
My lord.  

**DUKE VINCENTIO**  
Of government the properties to unfold,  
Would seem in me to affect speech and discourse;  
Since I am put to know that your own science  
Exceeds, in that, the lists of all advice  
My strength can give you: then no more remains,  
But that to your sufficiency as your Worth is able,  
And let them work. The nature of our people,  
Our city's institutions, and the terms  
For common justice, you're as pregnant in  
As art and practise hath enriched any  
That we remember. There is our commission,  
From which we would not have you warp. Call hither,  
I say, bid come before us Angelo.  

_Exit an Attendant_

What figure of us think you he will bear?  
For you must know, we have with special soul  
Elected him our absence to supply,  
Lent him our terror, dress'd him with our love,  
And given his deputation all the organs  
Of our own power: what think you of it?  

**ESCALUS**  
If any in Vienna be of worth  
To undergo such ample grace and honour,  
It is Lord Angelo.  

**DUKE VINCENTIO**  
Look where he comes.  

_Enter ANGELO_

**ANGELO**  
Always obedient to your grace's will,  
I come to know your pleasure.  

**DUKE VINCENTIO**  
Angelo,  
There is a kind of character in thy life,  
That to the observer doth thy history  
Fully unfold. Thyself and thy belongings  
Are not thine own so proper as to waste  
Thyself upon thy virtues, they on thee.  
Heaven doth with us as we with torches do,  
Not light them for themselves; for if our virtues  
Did not go forth of us, 'twere all alike  
As if we had them not. Spirits are not finely touch'd  
But to fine issues, nor Nature never lends  
The smallest scruple of her excellence  
But, like a thrifty goddess, she determines  
Herself the glory of a creditor,  
Both thanks and use. But I do bend my speech  
To one that can my part in him advertise;  
Hold therefore, Angelo:--  
In our remove be thou at full ourself;  
Mortality and mercy in Vienna  
Live in thy tongue and heart: old Escalus,  
Though first in question, is thy secondary.  
Take thy commission.  

**ANGELO**  
Now, good my lord,  
Let there be some more test made of my metal,  
Before so noble and so great a figure  
Be stamp'd upon it.  

**DUKE VINCENTIO**  
No more evasion:  
We have with a leaven'd and prepared choice  
Proceeded to you; therefore take your honours.  
Our haste from hence is of so quick condition  
That it prefers itself and leaves unquestion'd  
Matters of needful value. We shall write to you,  
As time and our concernings shall importune,  
How it goes with us, and do look to know  
What doth befall you here. So, fare you well;  
To the hopeful execution do I leave you  
Of your commissions.  

**ANGELO**  
Yet give leave, my lord,  
That we may bring you something on the way.  

**DUKE VINCENTIO**  
My haste may not admit it;  
Nor need you, on mine honour, have to do  
With any scruple; your scope is as mine own  
So to enforce or qualify the laws  
As to your soul seems good. Give me your hand:  
I'll privily away. I love the people,  
But do not like to stage me to their eyes:  
Through it do well, I do not relish well  
Their loud applause and Aves vehement;  
Nor do I think the man of safe discretion  
That does affect it. Once more, fare you well.  

**ANGELO**  
The heavens give safety to your purposes!  

**ESCALUS**  
Lead forth and bring you back in happiness!  

**DUKE**  
I thank you. Fare you well.  

_Exit_

**ESCALUS**  
I shall desire you, sir, to give me leave  
To have free speech with you; and it concerns me  
To look into the bottom of my place:  
A power I have, but of what strength and nature  
I am not yet instructed.  

**ANGELO**  
'Tis so with me. Let us withdraw together,  
And we may soon our satisfaction have  
Touching that point.  

**ESCALUS**  
I'll wait upon your honour.  

_Exeunt_

### SCENE II. A Street.

_Enter LUCIO and two Gentlemen_

**LUCIO**  
If the duke with the other dukes come not to  
composition with the King of Hungary, why then all  
the dukes fall upon the king.  

**First Gentleman**  
Heaven grant us its peace, but not the King of  
Hungary's!  

**Second Gentleman**  
Amen.  

**LUCIO**  
Thou concludest like the sanctimonious pirate, that  
went to sea with the Ten Commandments, but scraped  
one out of the table.  

**Second Gentleman**  
'Thou shalt not steal'?  

**LUCIO**  
Ay, that he razed.  

**First Gentleman**  
Why, 'twas a commandment to command the captain and  
all the rest from their functions: they put forth  
to steal. There's not a soldier of us all, that, in  
the thanksgiving before meat, do relish the petition  
well that prays for peace.  

**Second Gentleman**  
I never heard any soldier dislike it.  

**LUCIO**  
I believe thee; for I think thou never wast where  
grace was said.  

**Second Gentleman**  
No? a dozen times at least.  

**First Gentleman**  
What, in metre?  

**LUCIO**  
In any proportion or in any language.  

**First Gentleman**  
I think, or in any religion.  

**LUCIO**  
Ay, why not? Grace is grace, despite of all  
controversy: as, for example, thou thyself art a  
wicked villain, despite of all grace.  

**First Gentleman**  
Well, there went but a pair of shears between us.  

**LUCIO**  
I grant; as there may between the lists and the  
velvet. Thou art the list.  

**First Gentleman**  
And thou the velvet: thou art good velvet; thou'rt  
a three-piled piece, I warrant thee: I had as lief  
be a list of an English kersey as be piled, as thou  
art piled, for a French velvet. Do I speak  
feelingly now?  

**LUCIO**  
I think thou dost; and, indeed, with most painful  
feeling of thy speech: I will, out of thine own  
confession, learn to begin thy health; but, whilst I  
live, forget to drink after thee.  

**First Gentleman**  
I think I have done myself wrong, have I not?  

**Second Gentleman**  
Yes, that thou hast, whether thou art tainted or free.  

**LUCIO**  
Behold, behold. where Madam Mitigation comes! I  
have purchased as many diseases under her roof as come to--  

**Second Gentleman**  
To what, I pray?  

**LUCIO**  
Judge.  

**Second Gentleman**  
To three thousand dolours a year.  

**First Gentleman**  
Ay, and more.  

**LUCIO**  
A French crown more.  

**First Gentleman**  
Thou art always figuring diseases in me; but thou  
art full of error; I am sound.  

**LUCIO**  
Nay, not as one would say, healthy; but so sound as  
things that are hollow: thy bones are hollow;  
impiety has made a feast of thee.  

_Enter MISTRESS OVERDONE_

**First Gentleman**  
How now! which of your hips has the most profound sciatica?  

**MISTRESS OVERDONE**  
Well, well; there's one yonder arrested and carried  
to prison was worth five thousand of you all.  

**Second Gentleman**  
Who's that, I pray thee?  

**MISTRESS OVERDONE**  
Marry, sir, that's Claudio, Signior Claudio.  

**First Gentleman**  
Claudio to prison? 'tis not so.  

**MISTRESS OVERDONE**  
Nay, but I know 'tis so: I saw him arrested, saw  
him carried away; and, which is more, within these  
three days his head to be chopped off.  

**LUCIO**  
But, after all this fooling, I would not have it so.  
Art thou sure of this?  

**MISTRESS OVERDONE**  
I am too sure of it: and it is for getting Madam  
Julietta with child.  

**LUCIO**  
Believe me, this may be: he promised to meet me two  
hours since, and he was ever precise in  
promise-keeping.  

**Second Gentleman**  
Besides, you know, it draws something near to the  
speech we had to such a purpose.  

**First Gentleman**  
But, most of all, agreeing with the proclamation.  

**LUCIO**  
Away! let's go learn the truth of it.  

_Exeunt LUCIO and Gentlemen_

**MISTRESS OVERDONE**  
Thus, what with the war, what with the sweat, what  
with the gallows and what with poverty, I am  
custom-shrunk.  

_Enter POMPEY_

How now! what's the news with you?  

**POMPEY**  
Yonder man is carried to prison.  

**MISTRESS OVERDONE**  
Well; what has he done?  

**POMPEY**  
A woman.  

**MISTRESS OVERDONE**  
But what's his offence?  

**POMPEY**  
Groping for trouts in a peculiar river.  

**MISTRESS OVERDONE**  
What, is there a maid with child by him?  

**POMPEY**  
No, but there's a woman with maid by him. You have  
not heard of the proclamation, have you?  

**MISTRESS OVERDONE**  
What proclamation, man?  

**POMPEY**  
All houses in the suburbs of Vienna must be plucked down.  

**MISTRESS OVERDONE**  
And what shall become of those in the city?  

**POMPEY**  
They shall stand for seed: they had gone down too,  
but that a wise burgher put in for them.  

**MISTRESS OVERDONE**  
But shall all our houses of resort in the suburbs be  
pulled down?  

**POMPEY**  
To the ground, mistress.  

**MISTRESS OVERDONE**  
Why, here's a change indeed in the commonwealth!  
What shall become of me?  

**POMPEY**  
Come; fear you not: good counsellors lack no  
clients: though you change your place, you need not  
change your trade; I'll be your tapster still.  
Courage! there will be pity taken on you: you that  
have worn your eyes almost out in the service, you  
will be considered.  

**MISTRESS OVERDONE**  
What's to do here, Thomas tapster? let's withdraw.  

**POMPEY**  
Here comes Signior Claudio, led by the provost to  
prison; and there's Madam Juliet.  

_Exeunt_

_Enter Provost, CLAUDIO, JULIET, and Officers_

**CLAUDIO**  
Fellow, why dost thou show me thus to the world?  
Bear me to prison, where I am committed.  

**Provost**  
I do it not in evil disposition,  
But from Lord Angelo by special charge.  

**CLAUDIO**  
Thus can the demigod Authority  
Make us pay down for our offence by weight  
The words of heaven; on whom it will, it will;  
On whom it will not, so; yet still 'tis just.  

_Re-enter LUCIO and two Gentlemen_

**LUCIO**  
Why, how now, Claudio! whence comes this restraint?  

**CLAUDIO**  
From too much liberty, my Lucio, liberty:  
As surfeit is the father of much fast,  
So every scope by the immoderate use  
Turns to restraint. Our natures do pursue,  
Like rats that ravin down their proper bane,  
A thirsty evil; and when we drink we die.  

**LUCIO**  
If could speak so wisely under an arrest, I would  
send for certain of my creditors: and yet, to say  
the truth, I had as lief have the foppery of freedom  
as the morality of imprisonment. What's thy  
offence, Claudio?  

**CLAUDIO**  
What but to speak of would offend again.  

**LUCIO**  
What, is't murder?  

**CLAUDIO**  
No.  

**LUCIO**  
Lechery?  

**CLAUDIO**  
Call it so.  

**Provost**  
Away, sir! you must go.  

**CLAUDIO**  
One word, good friend. Lucio, a word with you.  

**LUCIO**  
A hundred, if they'll do you any good.  
Is lechery so look'd after?  

**CLAUDIO**  
Thus stands it with me: upon a true contract  
I got possession of Julietta's bed:  
You know the lady; she is fast my wife,  
Save that we do the denunciation lack  
Of outward order: this we came not to,  
Only for propagation of a dower  
Remaining in the coffer of her friends,  
From whom we thought it meet to hide our love  
Till time had made them for us. But it chances  
The stealth of our most mutual entertainment  
With character too gross is writ on Juliet.  

**LUCIO**  
With child, perhaps?  

**CLAUDIO**  
Unhappily, even so.  
And the new deputy now for the duke--  
Whether it be the fault and glimpse of newness,  
Or whether that the body public be  
A horse whereon the governor doth ride,  
Who, newly in the seat, that it may know  
He can command, lets it straight feel the spur;  
Whether the tyranny be in his place,  
Or in his emmence that fills it up,  
I stagger in:--but this new governor  
Awakes me all the enrolled penalties  
Which have, like unscour'd armour, hung by the wall  
So long that nineteen zodiacs have gone round  
And none of them been worn; and, for a name,  
Now puts the drowsy and neglected act  
Freshly on me: 'tis surely for a name.  

**LUCIO**  
I warrant it is: and thy head stands so tickle on  
thy shoulders that a milkmaid, if she be in love,  
may sigh it off. Send after the duke and appeal to  
him.  

**CLAUDIO**  
I have done so, but he's not to be found.  
I prithee, Lucio, do me this kind service:  
This day my sister should the cloister enter  
And there receive her approbation:  
Acquaint her with the danger of my state:  
Implore her, in my voice, that she make friends  
To the strict deputy; bid herself assay him:  
I have great hope in that; for in her youth  
There is a prone and speechless dialect,  
Such as move men; beside, she hath prosperous art  
When she will play with reason and discourse,  
And well she can persuade.  

**LUCIO**  
I pray she may; as well for the encouragement of the  
like, which else would stand under grievous  
imposition, as for the enjoying of thy life, who I  
would be sorry should be thus foolishly lost at a  
game of tick-tack. I'll to her.  

**CLAUDIO**  
I thank you, good friend Lucio.  

**LUCIO**  
Within two hours.  

**CLAUDIO**  
Come, officer, away!  

_Exeunt_

### SCENE III. A monastery.

_Enter DUKE VINCENTIO and FRIAR THOMAS_

**DUKE VINCENTIO**  
No, holy father; throw away that thought;  
Believe not that the dribbling dart of love  
Can pierce a complete bosom. Why I desire thee  
To give me secret harbour, hath a purpose  
More grave and wrinkled than the aims and ends  
Of burning youth.  

**FRIAR THOMAS**  
May your grace speak of it?  

**DUKE VINCENTIO**  
My holy sir, none better knows than you  
How I have ever loved the life removed  
And held in idle price to haunt assemblies  
Where youth, and cost, and witless bravery keeps.  
I have deliver'd to Lord Angelo,  
A man of stricture and firm abstinence,  
My absolute power and place here in Vienna,  
And he supposes me travell'd to Poland;  
For so I have strew'd it in the common ear,  
And so it is received. Now, pious sir,  
You will demand of me why I do this?  

**FRIAR THOMAS**  
Gladly, my lord.  

**DUKE VINCENTIO**  
We have strict statutes and most biting laws.  
The needful bits and curbs to headstrong weeds,  
Which for this nineteen years we have let slip;  
Even like an o'ergrown lion in a cave,  
That goes not out to prey. Now, as fond fathers,  
Having bound up the threatening twigs of birch,  
Only to stick it in their children's sight  
For terror, not to use, in time the rod  
Becomes more mock'd than fear'd; so our decrees,  
Dead to infliction, to themselves are dead;  
And liberty plucks justice by the nose;  
The baby beats the nurse, and quite athwart  
Goes all decorum.  

**FRIAR THOMAS**  
It rested in your grace  
To unloose this tied-up justice when you pleased:  
And it in you more dreadful would have seem'd  
Than in Lord Angelo.  

**DUKE VINCENTIO**  
I do fear, too dreadful:  
Sith 'twas my fault to give the people scope,  
'Twould be my tyranny to strike and gall them  
For what I bid them do: for we bid this be done,  
When evil deeds have their permissive pass  
And not the punishment. Therefore indeed, my father,  
I have on Angelo imposed the office;  
Who may, in the ambush of my name, strike home,  
And yet my nature never in the fight  
To do in slander. And to behold his sway,  
I will, as 'twere a brother of your order,  
Visit both prince and people: therefore, I prithee,  
Supply me with the habit and instruct me  
How I may formally in person bear me  
Like a true friar. More reasons for this action  
At our more leisure shall I render you;  
Only, this one: Lord Angelo is precise;  
Stands at a guard with envy; scarce confesses  
That his blood flows, or that his appetite  
Is more to bread than stone: hence shall we see,  
If power change purpose, what our seemers be.  

_Exeunt_

### SCENE IV. A nunnery.

_Enter ISABELLA and FRANCISCA_

**ISABELLA**  
And have you nuns no farther privileges?  

**FRANCISCA**  
Are not these large enough?  

**ISABELLA**  
Yes, truly; I speak not as desiring more;  
But rather wishing a more strict restraint  
Upon the sisterhood, the votarists of Saint Clare.  

**LUCIO**  
_[Within]_  
Ho! Peace be in this place!  

**ISABELLA**  
Who's that which calls?  

**FRANCISCA**  
It is a man's voice. Gentle Isabella,  
Turn you the key, and know his business of him;  
You may, I may not; you are yet unsworn.  
When you have vow'd, you must not speak with men  
But in the presence of the prioress:  
Then, if you speak, you must not show your face,  
Or, if you show your face, you must not speak.  
He calls again; I pray you, answer him.  

_Exit_

**ISABELLA**  
Peace and prosperity! Who is't that calls  

_Enter LUCIO_

**LUCIO**  
Hail, virgin, if you be, as those cheek-roses  
Proclaim you are no less! Can you so stead me  
As bring me to the sight of Isabella,  
A novice of this place and the fair sister  
To her unhappy brother Claudio?  

**ISABELLA**  
Why 'her unhappy brother'? let me ask,  
The rather for I now must make you know  
I am that Isabella and his sister.  

**LUCIO**  
Gentle and fair, your brother kindly greets you:  
Not to be weary with you, he's in prison.  

**ISABELLA**  
Woe me! for what?  

**LUCIO**  
For that which, if myself might be his judge,  
He should receive his punishment in thanks:  
He hath got his friend with child.  

**ISABELLA**  
Sir, make me not your story.  

**LUCIO**  
It is true.  
I would not--though 'tis my familiar sin  
With maids to seem the lapwing and to jest,  
Tongue far from heart--play with all virgins so:  
I hold you as a thing ensky'd and sainted.  
By your renouncement an immortal spirit,  
And to be talk'd with in sincerity,  
As with a saint.  

**ISABELLA**  
You do blaspheme the good in mocking me.  

**LUCIO**  
Do not believe it. Fewness and truth, 'tis thus:  
Your brother and his lover have embraced:  
As those that feed grow full, as blossoming time  
That from the seedness the bare fallow brings  
To teeming foison, even so her plenteous womb  
Expresseth his full tilth and husbandry.  

**ISABELLA**  
Some one with child by him? My cousin Juliet?  

**LUCIO**  
Is she your cousin?  

**ISABELLA**  
Adoptedly; as school-maids change their names  
By vain though apt affection.  

**LUCIO**  
She it is.  

**ISABELLA**  
O, let him marry her.  

**LUCIO**  
This is the point.  
The duke is very strangely gone from hence;  
Bore many gentlemen, myself being one,  
In hand and hope of action: but we do learn  
By those that know the very nerves of state,  
His givings-out were of an infinite distance  
From his true-meant design. Upon his place,  
And with full line of his authority,  
Governs Lord Angelo; a man whose blood  
Is very snow-broth; one who never feels  
The wanton stings and motions of the sense,  
But doth rebate and blunt his natural edge  
With profits of the mind, study and fast.  
He--to give fear to use and liberty,  
Which have for long run by the hideous law,  
As mice by lions--hath pick'd out an act,  
Under whose heavy sense your brother's life  
Falls into forfeit: he arrests him on it;  
And follows close the rigour of the statute,  
To make him an example. All hope is gone,  
Unless you have the grace by your fair prayer  
To soften Angelo: and that's my pith of business  
'Twixt you and your poor brother.  

**ISABELLA**  
Doth he so seek his life?  

**LUCIO**  
Has censured him  
Already; and, as I hear, the provost hath  
A warrant for his execution.  

**ISABELLA**  
Alas! what poor ability's in me  
To do him good?  

**LUCIO**  
Assay the power you have.  

**ISABELLA**  
My power? Alas, I doubt--  

**LUCIO**  
Our doubts are traitors  
And make us lose the good we oft might win  
By fearing to attempt. Go to Lord Angelo,  
And let him learn to know, when maidens sue,  
Men give like gods; but when they weep and kneel,  
All their petitions are as freely theirs  
As they themselves would owe them.  

**ISABELLA**  
I'll see what I can do.  

**LUCIO**  
But speedily.  

**ISABELLA**  
I will about it straight;  
No longer staying but to give the mother  
Notice of my affair. I humbly thank you:  
Commend me to my brother: soon at night  
I'll send him certain word of my success.  

**LUCIO**  
I take my leave of you.  

**ISABELLA**  
Good sir, adieu.  

_Exeunt_

# ACT II

### SCENE I. A hall In ANGELO's house.

_Enter ANGELO, ESCALUS, and a Justice, Provost, Officers, and other
Attendants, behind_

**ANGELO**  
We must not make a scarecrow of the law,  
Setting it up to fear the birds of prey,  
And let it keep one shape, till custom make it  
Their perch and not their terror.  

**ESCALUS**  
Ay, but yet  
Let us be keen, and rather cut a little,  
Than fall, and bruise to death. Alas, this gentleman  
Whom I would save, had a most noble father!  
Let but your honour know,  
Whom I believe to be most strait in virtue,  
That, in the working of your own affections,  
Had time cohered with place or place with wishing,  
Or that the resolute acting of your blood  
Could have attain'd the effect of your own purpose,  
Whether you had not sometime in your life  
Err'd in this point which now you censure him,  
And pull'd the law upon you.  

**ANGELO**  
'Tis one thing to be tempted, Escalus,  
Another thing to fall. I not deny,  
The jury, passing on the prisoner's life,  
May in the sworn twelve have a thief or two  
Guiltier than him they try. What's open made to justice,  
That justice seizes: what know the laws  
That thieves do pass on thieves? 'Tis very pregnant,  
The jewel that we find, we stoop and take't  
Because we see it; but what we do not see  
We tread upon, and never think of it.  
You may not so extenuate his offence  
For I have had such faults; but rather tell me,  
When I, that censure him, do so offend,  
Let mine own judgment pattern out my death,  
And nothing come in partial. Sir, he must die.  

**ESCALUS**  
Be it as your wisdom will.  

**ANGELO**  
Where is the provost?  

**Provost**  
Here, if it like your honour.  

**ANGELO**  
See that Claudio  
Be executed by nine to-morrow morning:  
Bring him his confessor, let him be prepared;  
For that's the utmost of his pilgrimage.  

_Exit Provost_

**ESCALUS**  
_[Aside]_  
Well, heaven forgive him! and forgive us all!  
Some rise by sin, and some by virtue fall:  
Some run from brakes of ice, and answer none:  
And some condemned for a fault alone.  

_Enter ELBOW, and Officers with FROTH and POMPEY_

**ELBOW**  
Come, bring them away: if these be good people in  
a commonweal that do nothing but use their abuses in  
common houses, I know no law: bring them away.  

**ANGELO**  
How now, sir! What's your name? and what's the matter?  

**ELBOW**  
If it Please your honour, I am the poor duke's  
constable, and my name is Elbow: I do lean upon  
justice, sir, and do bring in here before your good  
honour two notorious benefactors.  

**ANGELO**  
Benefactors? Well; what benefactors are they? are  
they not malefactors?  

**ELBOW**  
If it? please your honour, I know not well what they  
are: but precise villains they are, that I am sure  
of; and void of all profanation in the world that  
good Christians ought to have.  

**ESCALUS**  
This comes off well; here's a wise officer.  

**ANGELO**  
Go to: what quality are they of? Elbow is your  
name? why dost thou not speak, Elbow?  

**POMPEY**  
He cannot, sir; he's out at elbow.  

**ANGELO**  
What are you, sir?  

**ELBOW**  
He, sir! a tapster, sir; parcel-bawd; one that  
serves a bad woman; whose house, sir, was, as they  
say, plucked down in the suburbs; and now she  
professes a hot-house, which, I think, is a very ill house too.  

**ESCALUS**  
How know you that?  

**ELBOW**  
My wife, sir, whom I detest before heaven and your honour,--  

**ESCALUS**  
How? thy wife?  

**ELBOW**  
Ay, sir; whom, I thank heaven, is an honest woman,--  

**ESCALUS**  
Dost thou detest her therefore?  

**ELBOW**  
I say, sir, I will detest myself also, as well as  
she, that this house, if it be not a bawd's house,  
it is pity of her life, for it is a naughty house.  

**ESCALUS**  
How dost thou know that, constable?  

**ELBOW**  
Marry, sir, by my wife; who, if she had been a woman  
cardinally given, might have been accused in  
fornication, adultery, and all uncleanliness there.  

**ESCALUS**  
By the woman's means?  

**ELBOW**  
Ay, sir, by Mistress Overdone's means: but as she  
spit in his face, so she defied him.  

**POMPEY**  
Sir, if it please your honour, this is not so.  

**ELBOW**  
Prove it before these varlets here, thou honourable  
man; prove it.  

**ESCALUS**  
Do you hear how he misplaces?  

**POMPEY**  
Sir, she came in great with child; and longing,  
saving your honour's reverence, for stewed prunes;  
sir, we had but two in the house, which at that very  
distant time stood, as it were, in a fruit-dish, a  
dish of some three-pence; your honours have seen  
such dishes; they are not China dishes, but very  
good dishes,--  

**ESCALUS**  
Go to, go to: no matter for the dish, sir.  

**POMPEY**  
No, indeed, sir, not of a pin; you are therein in  
the right: but to the point. As I say, this  
Mistress Elbow, being, as I say, with child, and  
being great-bellied, and longing, as I said, for  
prunes; and having but two in the dish, as I said,  
Master Froth here, this very man, having eaten the  
rest, as I said, and, as I say, paying for them very  
honestly; for, as you know, Master Froth, I could  
not give you three-pence again.  

**FROTH**  
No, indeed.  

**POMPEY**  
Very well: you being then, if you be remembered,  
cracking the stones of the foresaid prunes,--  

**FROTH**  
Ay, so I did indeed.  

**POMPEY**  
Why, very well; I telling you then, if you be  
remembered, that such a one and such a one were past  
cure of the thing you wot of, unless they kept very  
good diet, as I told you,--  

**FROTH**  
All this is true.  

**POMPEY**  
Why, very well, then,--  

**ESCALUS**  
Come, you are a tedious fool: to the purpose. What  
was done to Elbow's wife, that he hath cause to  
complain of? Come me to what was done to her.  

**POMPEY**  
Sir, your honour cannot come to that yet.  

**ESCALUS**  
No, sir, nor I mean it not.  

**POMPEY**  
Sir, but you shall come to it, by your honour's  
leave. And, I beseech you, look into Master Froth  
here, sir; a man of four-score pound a year; whose  
father died at Hallowmas: was't not at Hallowmas,  
Master Froth?  

**FROTH**  
All-hallond eve.  

**POMPEY**  
Why, very well; I hope here be truths. He, sir,  
sitting, as I say, in a lower chair, sir; 'twas in  
the Bunch of Grapes, where indeed you have a delight  
to sit, have you not?  

**FROTH**  
I have so; because it is an open room and good for winter.  

**POMPEY**  
Why, very well, then; I hope here be truths.  

**ANGELO**  
This will last out a night in Russia,  
When nights are longest there: I'll take my leave.  
And leave you to the hearing of the cause;  
Hoping you'll find good cause to whip them all.  

**ESCALUS**  
I think no less. Good morrow to your lordship.  

_Exit ANGELO_

Now, sir, come on: what was done to Elbow's wife, once more?  

**POMPEY**  
Once, sir? there was nothing done to her once.  

**ELBOW**  
I beseech you, sir, ask him what this man did to my wife.  

**POMPEY**  
I beseech your honour, ask me.  

**ESCALUS**  
Well, sir; what did this gentleman to her?  

**POMPEY**  
I beseech you, sir, look in this gentleman's face.  
Good Master Froth, look upon his honour; 'tis for a  
good purpose. Doth your honour mark his face?  

**ESCALUS**  
Ay, sir, very well.  

**POMPEY**  
Nay; I beseech you, mark it well.  

**ESCALUS**  
Well, I do so.  

**POMPEY**  
Doth your honour see any harm in his face?  

**ESCALUS**  
Why, no.  

**POMPEY**  
I'll be supposed upon a book, his face is the worst  
thing about him. Good, then; if his face be the  
worst thing about him, how could Master Froth do the  
constable's wife any harm? I would know that of  
your honour.  

**ESCALUS**  
He's in the right. Constable, what say you to it?  

**ELBOW**  
First, an it like you, the house is a respected  
house; next, this is a respected fellow; and his  
mistress is a respected woman.  

**POMPEY**  
By this hand, sir, his wife is a more respected  
person than any of us all.  

**ELBOW**  
Varlet, thou liest; thou liest, wicked varlet! the  
time has yet to come that she was ever respected  
with man, woman, or child.  

**POMPEY**  
Sir, she was respected with him before he married with her.  

**ESCALUS**  
Which is the wiser here? Justice or Iniquity? Is  
this true?  

**ELBOW**  
O thou caitiff! O thou varlet! O thou wicked  
Hannibal! I respected with her before I was married  
to her! If ever I was respected with her, or she  
with me, let not your worship think me the poor  
duke's officer. Prove this, thou wicked Hannibal, or  
I'll have mine action of battery on thee.  

**ESCALUS**  
If he took you a box o' the ear, you might have your  
action of slander too.  

**ELBOW**  
Marry, I thank your good worship for it. What is't  
your worship's pleasure I shall do with this wicked caitiff?  

**ESCALUS**  
Truly, officer, because he hath some offences in him  
that thou wouldst discover if thou couldst, let him  
continue in his courses till thou knowest what they  
are.  

**ELBOW**  
Marry, I thank your worship for it. Thou seest, thou  
wicked varlet, now, what's come upon thee: thou art  
to continue now, thou varlet; thou art to continue.  

**ESCALUS**  
Where were you born, friend?  

**FROTH**  
Here in Vienna, sir.  

**ESCALUS**  
Are you of fourscore pounds a year?  

**FROTH**  
Yes, an't please you, sir.  

**ESCALUS**  
So. What trade are you of, sir?  

**POMPHEY**  
Tapster; a poor widow's tapster.  

**ESCALUS**  
Your mistress' name?  

**POMPHEY**  
Mistress Overdone.  

**ESCALUS**  
Hath she had any more than one husband?  

**POMPEY**  
Nine, sir; Overdone by the last.  

**ESCALUS**  
Nine! Come hither to me, Master Froth. Master  
Froth, I would not have you acquainted with  
tapsters: they will draw you, Master Froth, and you  
will hang them. Get you gone, and let me hear no  
more of you.  

**FROTH**  
I thank your worship. For mine own part, I never  
come into any room in a tap-house, but I am drawn  
in.  

**ESCALUS**  
Well, no more of it, Master Froth: farewell.  

_Exit FROTH_

Come you hither to me, Master tapster. What's your  
name, Master tapster?  

**POMPEY**  
Pompey.  

**ESCALUS**  
What else?  

**POMPEY**  
Bum, sir.  

**ESCALUS**  
Troth, and your bum is the greatest thing about you;  
so that in the beastliest sense you are Pompey the  
Great. Pompey, you are partly a bawd, Pompey,  
howsoever you colour it in being a tapster, are you  
not? come, tell me true: it shall be the better for you.  

**POMPEY**  
Truly, sir, I am a poor fellow that would live.  

**ESCALUS**  
How would you live, Pompey? by being a bawd? What  
do you think of the trade, Pompey? is it a lawful trade?  

**POMPEY**  
If the law would allow it, sir.  

**ESCALUS**  
But the law will not allow it, Pompey; nor it shall  
not be allowed in Vienna.  

**POMPEY**  
Does your worship mean to geld and splay all the  
youth of the city?  

**ESCALUS**  
No, Pompey.  

**POMPEY**  
Truly, sir, in my poor opinion, they will to't then.  
If your worship will take order for the drabs and  
the knaves, you need not to fear the bawds.  

**ESCALUS**  
There are pretty orders beginning, I can tell you:  
it is but heading and hanging.  

**POMPEY**  
If you head and hang all that offend that way but  
for ten year together, you'll be glad to give out a  
commission for more heads: if this law hold in  
Vienna ten year, I'll rent the fairest house in it  
after three-pence a bay: if you live to see this  
come to pass, say Pompey told you so.  

**ESCALUS**  
Thank you, good Pompey; and, in requital of your  
prophecy, hark you: I advise you, let me not find  
you before me again upon any complaint whatsoever;  
no, not for dwelling where you do: if I do, Pompey,  
I shall beat you to your tent, and prove a shrewd  
Caesar to you; in plain dealing, Pompey, I shall  
have you whipt: so, for this time, Pompey, fare you well.  

**POMPEY**  
I thank your worship for your good counsel:  

_[Aside]_  
but I shall follow it as the flesh and fortune shall  
better determine.  
Whip me? No, no; let carman whip his jade:  
The valiant heart is not whipt out of his trade.  

_Exit_

**ESCALUS**  
Come hither to me, Master Elbow; come hither, Master  
constable. How long have you been in this place of constable?  

**ELBOW**  
Seven year and a half, sir.  

**ESCALUS**  
I thought, by your readiness in the office, you had  
continued in it some time. You say, seven years together?  

**ELBOW**  
And a half, sir.  

**ESCALUS**  
Alas, it hath been great pains to you. They do you  
wrong to put you so oft upon 't: are there not men  
in your ward sufficient to serve it?  

**ELBOW**  
Faith, sir, few of any wit in such matters: as they  
are chosen, they are glad to choose me for them; I  
do it for some piece of money, and go through with  
all.  

**ESCALUS**  
Look you bring me in the names of some six or seven,  
the most sufficient of your parish.  

**ELBOW**  
To your worship's house, sir?  

**ESCALUS**  
To my house. Fare you well.  

_Exit ELBOW_

What's o'clock, think you?  

**Justice**  
Eleven, sir.  

**ESCALUS**  
I pray you home to dinner with me.  

**Justice**  
I humbly thank you.  

**ESCALUS**  
It grieves me for the death of Claudio;  
But there's no remedy.  

**Justice**  
Lord Angelo is severe.  

**ESCALUS**  
It is but needful:  
Mercy is not itself, that oft looks so;  
Pardon is still the nurse of second woe:  
But yet,--poor Claudio! There is no remedy.  
Come, sir.  

_Exeunt_

### SCENE II. Another room in the same.

_Enter Provost and a Servant_

**Servant**  
He's hearing of a cause; he will come straight  
I'll tell him of you.  

**Provost**  
Pray you, do.  

_Exit Servant_

I'll know  
His pleasure; may be he will relent. Alas,  
He hath but as offended in a dream!  
All sects, all ages smack of this vice; and he  
To die for't!  

_Enter ANGELO_

**ANGELO**  
Now, what's the matter. Provost?  

**Provost**  
Is it your will Claudio shall die tomorrow?  

**ANGELO**  
Did not I tell thee yea? hadst thou not order?  
Why dost thou ask again?  

**Provost**  
Lest I might be too rash:  
Under your good correction, I have seen,  
When, after execution, judgment hath  
Repented o'er his doom.  

**ANGELO**  
Go to; let that be mine:  
Do you your office, or give up your place,  
And you shall well be spared.  

**Provost**  
I crave your honour's pardon.  
What shall be done, sir, with the groaning Juliet?  
She's very near her hour.  

**ANGELO**  
Dispose of her  
To some more fitter place, and that with speed.  

_Re-enter Servant_

**Servant**  
Here is the sister of the man condemn'd  
Desires access to you.  

**ANGELO**  
Hath he a sister?  

**Provost**  
Ay, my good lord; a very virtuous maid,  
And to be shortly of a sisterhood,  
If not already.  

**ANGELO**  
Well, let her be admitted.  

_Exit Servant_

See you the fornicatress be removed:  
Let have needful, but not lavish, means;  
There shall be order for't.  

_Enter ISABELLA and LUCIO_

**Provost**  
God save your honour!  

**ANGELO**  
Stay a little while.  

_[To ISABELLA]_  
You're welcome: what's your will?  

**ISABELLA**  
I am a woeful suitor to your honour,  
Please but your honour hear me.  

**ANGELO**  
Well; what's your suit?  

**ISABELLA**  
There is a vice that most I do abhor,  
And most desire should meet the blow of justice;  
For which I would not plead, but that I must;  
For which I must not plead, but that I am  
At war 'twixt will and will not.  

**ANGELO**  
Well; the matter?  

**ISABELLA**  
I have a brother is condemn'd to die:  
I do beseech you, let it be his fault,  
And not my brother.  

**Provost**  
_[Aside]_  
Heaven give thee moving graces!  

**ANGELO**  
Condemn the fault and not the actor of it?  
Why, every fault's condemn'd ere it be done:  
Mine were the very cipher of a function,  
To fine the faults whose fine stands in record,  
And let go by the actor.  

**ISABELLA**  
O just but severe law!  
I had a brother, then. Heaven keep your honour!  

**LUCIO**  
_[Aside to ISABELLA]_  
Give't not o'er so: to him  
again, entreat him;  
Kneel down before him, hang upon his gown:  
You are too cold; if you should need a pin,  
You could not with more tame a tongue desire it:  
To him, I say!  

**ISABELLA**  
Must he needs die?  

**ANGELO**  
Maiden, no remedy.  

**ISABELLA**  
Yes; I do think that you might pardon him,  
And neither heaven nor man grieve at the mercy.  

**ANGELO**  
I will not do't.  

**ISABELLA**  
But can you, if you would?  

**ANGELO**  
Look, what I will not, that I cannot do.  

**ISABELLA**  
But might you do't, and do the world no wrong,  
If so your heart were touch'd with that remorse  
A s mine is to him?  

**ANGELO**  
He's sentenced; 'tis too late.  

**LUCIO**  
_[Aside to ISABELLA]_  
You are too cold.  

**ISABELLA**  
Too late? why, no; I, that do speak a word.  
May call it back again. Well, believe this,  
No ceremony that to great ones 'longs,  
Not the king's crown, nor the deputed sword,  
The marshal's truncheon, nor the judge's robe,  
Become them with one half so good a grace  
As mercy does.  
If he had been as you and you as he,  
You would have slipt like him; but he, like you,  
Would not have been so stern.  

**ANGELO**  
Pray you, be gone.  

**ISABELLA**  
I would to heaven I had your potency,  
And you were Isabel! should it then be thus?  
No; I would tell what 'twere to be a judge,  
And what a prisoner.  

**LUCIO**  
_[Aside to ISABELLA]_  
Ay, touch him; there's the vein.  

**ANGELO**  
Your brother is a forfeit of the law,  
And you but waste your words.  

**ISABELLA**  
Alas, alas!  
Why, all the souls that were were forfeit once;  
And He that might the vantage best have took  
Found out the remedy. How would you be,  
If He, which is the top of judgment, should  
But judge you as you are? O, think on that;  
And mercy then will breathe within your lips,  
Like man new made.  

**ANGELO**  
Be you content, fair maid;  
It is the law, not I condemn your brother:  
Were he my kinsman, brother, or my son,  
It should be thus with him: he must die tomorrow.  

**ISABELLA**  
To-morrow! O, that's sudden! Spare him, spare him!  
He's not prepared for death. Even for our kitchens  
We kill the fowl of season: shall we serve heaven  
With less respect than we do minister  
To our gross selves? Good, good my lord, bethink you;  
Who is it that hath died for this offence?  
There's many have committed it.  

**LUCIO**  
_[Aside to ISABELLA]_  
Ay, well said.  

**ANGELO**  
The law hath not been dead, though it hath slept:  
Those many had not dared to do that evil,  
If the first that did the edict infringe  
Had answer'd for his deed: now 'tis awake  
Takes note of what is done; and, like a prophet,  
Looks in a glass, that shows what future evils,  
Either new, or by remissness new-conceived,  
And so in progress to be hatch'd and born,  
Are now to have no successive degrees,  
But, ere they live, to end.  

**ISABELLA**  
Yet show some pity.  

**ANGELO**  
I show it most of all when I show justice;  
For then I pity those I do not know,  
Which a dismiss'd offence would after gall;  
And do him right that, answering one foul wrong,  
Lives not to act another. Be satisfied;  
Your brother dies to-morrow; be content.  

**ISABELLA**  
So you must be the first that gives this sentence,  
And he, that suffer's. O, it is excellent  
To have a giant's strength; but it is tyrannous  
To use it like a giant.  

**LUCIO**  
_[Aside to ISABELLA]_  
That's well said.  

**ISABELLA**  
Could great men thunder  
As Jove himself does, Jove would ne'er be quiet,  
For every pelting, petty officer  
Would use his heaven for thunder;  
Nothing but thunder! Merciful Heaven,  
Thou rather with thy sharp and sulphurous bolt  
Split'st the unwedgeable and gnarled oak  
Than the soft myrtle: but man, proud man,  
Drest in a little brief authority,  
Most ignorant of what he's most assured,  
His glassy essence, like an angry ape,  
Plays such fantastic tricks before high heaven  
As make the angels weep; who, with our spleens,  
Would all themselves laugh mortal.  

**LUCIO**  
_[Aside to ISABELLA]_  
O, to him, to him, wench! he  
will relent;  
He's coming; I perceive 't.  

**Provost**  
_[Aside]_  
Pray heaven she win him!  

**ISABELLA**  
We cannot weigh our brother with ourself:  
Great men may jest with saints; 'tis wit in them,  
But in the less foul profanation.  

**LUCIO**  
Thou'rt i' the right, girl; more o, that.  

**ISABELLA**  
That in the captain's but a choleric word,  
Which in the soldier is flat blasphemy.  

**LUCIO**  
_[Aside to ISABELLA]_  
Art avised o' that? more on 't.  

**ANGELO**  
Why do you put these sayings upon me?  

**ISABELLA**  
Because authority, though it err like others,  
Hath yet a kind of medicine in itself,  
That skins the vice o' the top. Go to your bosom;  
Knock there, and ask your heart what it doth know  
That's like my brother's fault: if it confess  
A natural guiltiness such as is his,  
Let it not sound a thought upon your tongue  
Against my brother's life.  

**ANGELO**  
_[Aside]_  
She speaks, and 'tis  
Such sense, that my sense breeds with it. Fare you well.  

**ISABELLA**  
Gentle my lord, turn back.  

**ANGELO**  
I will bethink me: come again tomorrow.  

**ISABELLA**  
Hark how I'll bribe you: good my lord, turn back.  

**ANGELO**  
How! bribe me?  

**ISABELLA**  
Ay, with such gifts that heaven shall share with you.  

**LUCIO**  
_[Aside to ISABELLA]_  
You had marr'd all else.  

**ISABELLA**  
Not with fond shekels of the tested gold,  
Or stones whose rates are either rich or poor  
As fancy values them; but with true prayers  
That shall be up at heaven and enter there  
Ere sun-rise, prayers from preserved souls,  
From fasting maids whose minds are dedicate  
To nothing temporal.  

**ANGELO**  
Well; come to me to-morrow.  

**LUCIO**  
_[Aside to ISABELLA]_  
Go to; 'tis well; away!  

**ISABELLA**  
Heaven keep your honour safe!  

**ANGELO**  
_[Aside]_  
Amen:  
For I am that way going to temptation,  
Where prayers cross.  

**ISABELLA**  
At what hour to-morrow  
Shall I attend your lordship?  

**ANGELO**  
At any time 'fore noon.  

**ISABELLA**  
'Save your honour!  

_Exeunt ISABELLA, LUCIO, and Provost_

**ANGELO**  
From thee, even from thy virtue!  
What's this, what's this? Is this her fault or mine?  
The tempter or the tempted, who sins most?  
Ha!  
Not she: nor doth she tempt: but it is I  
That, lying by the violet in the sun,  
Do as the carrion does, not as the flower,  
Corrupt with virtuous season. Can it be  
That modesty may more betray our sense  
Than woman's lightness? Having waste ground enough,  
Shall we desire to raze the sanctuary  
And pitch our evils there? O, fie, fie, fie!  
What dost thou, or what art thou, Angelo?  
Dost thou desire her foully for those things  
That make her good? O, let her brother live!  
Thieves for their robbery have authority  
When judges steal themselves. What, do I love her,  
That I desire to hear her speak again,  
And feast upon her eyes? What is't I dream on?  
O cunning enemy, that, to catch a saint,  
With saints dost bait thy hook! Most dangerous  
Is that temptation that doth goad us on  
To sin in loving virtue: never could the strumpet,  
With all her double vigour, art and nature,  
Once stir my temper; but this virtuous maid  
Subdues me quite. Even till now,  
When men were fond, I smiled and wonder'd how.  

_Exit_

### SCENE III. A room in a prison.

_Enter, severally, DUKE VINCENTIO disguised as a friar, and Provost_

**DUKE VINCENTIO**  
Hail to you, provost! so I think you are.  

**Provost**  
I am the provost. What's your will, good friar?  

**DUKE VINCENTIO**  
Bound by my charity and my blest order,  
I come to visit the afflicted spirits  
Here in the prison. Do me the common right  
To let me see them and to make me know  
The nature of their crimes, that I may minister  
To them accordingly.  

**Provost**  
I would do more than that, if more were needful.  

_Enter JULIET_

Look, here comes one: a gentlewoman of mine,  
Who, falling in the flaws of her own youth,  
Hath blister'd her report: she is with child;  
And he that got it, sentenced; a young man  
More fit to do another such offence  
Than die for this.  

**DUKE VINCENTIO**  
When must he die?  

**Provost**  
As I do think, to-morrow.  
I have provided for you: stay awhile,  

_[To JULIET]_  
And you shall be conducted.  

**DUKE VINCENTIO**  
Repent you, fair one, of the sin you carry?  

**JULIET**  
I do; and bear the shame most patiently.  

**DUKE VINCENTIO**  
I'll teach you how you shall arraign your conscience,  
And try your penitence, if it be sound,  
Or hollowly put on.  

**JULIET**  
I'll gladly learn.  

**DUKE VINCENTIO**  
Love you the man that wrong'd you?  

**JULIET**  
Yes, as I love the woman that wrong'd him.  

**DUKE VINCENTIO**  
So then it seems your most offenceful act  
Was mutually committed?  

**JULIET**  
Mutually.  

**DUKE VINCENTIO**  
Then was your sin of heavier kind than his.  

**JULIET**  
I do confess it, and repent it, father.  

**DUKE VINCENTIO**  
'Tis meet so, daughter: but lest you do repent,  
As that the sin hath brought you to this shame,  
Which sorrow is always towards ourselves, not heaven,  
Showing we would not spare heaven as we love it,  
But as we stand in fear,--  

**JULIET**  
I do repent me, as it is an evil,  
And take the shame with joy.  

**DUKE VINCENTIO**  
There rest.  
Your partner, as I hear, must die to-morrow,  
And I am going with instruction to him.  
Grace go with you, Benedicite!  

_Exit_

**JULIET**  
Must die to-morrow! O injurious love,  
That respites me a life, whose very comfort  
Is still a dying horror!  

**Provost**  
'Tis pity of him.  

_Exeunt_

### SCENE IV. A room in ANGELO's house.

_Enter ANGELO_

**ANGELO**  
When I would pray and think, I think and pray  
To several subjects. Heaven hath my empty words;  
Whilst my invention, hearing not my tongue,  
Anchors on Isabel: Heaven in my mouth,  
As if I did but only chew his name;  
And in my heart the strong and swelling evil  
Of my conception. The state, whereon I studied  
Is like a good thing, being often read,  
Grown fear'd and tedious; yea, my gravity,  
Wherein--let no man hear me--I take pride,  
Could I with boot change for an idle plume,  
Which the air beats for vain. O place, O form,  
How often dost thou with thy case, thy habit,  
Wrench awe from fools and tie the wiser souls  
To thy false seeming! Blood, thou art blood:  
Let's write good angel on the devil's horn:  
'Tis not the devil's crest.  

_Enter a Servant_

How now! who's there?  

**Servant**  
One Isabel, a sister, desires access to you.  

**ANGELO**  
Teach her the way.  

_Exit Servant_

O heavens!  
Why does my blood thus muster to my heart,  
Making both it unable for itself,  
And dispossessing all my other parts  
Of necessary fitness?  
So play the foolish throngs with one that swoons;  
Come all to help him, and so stop the air  
By which he should revive: and even so  
The general, subject to a well-wish'd king,  
Quit their own part, and in obsequious fondness  
Crowd to his presence, where their untaught love  
Must needs appear offence.  

_Enter ISABELLA_

How now, fair maid?  

**ISABELLA**  
I am come to know your pleasure.  

**ANGELO**  
That you might know it, would much better please me  
Than to demand what 'tis. Your brother cannot live.  

**ISABELLA**  
Even so. Heaven keep your honour!  

**ANGELO**  
Yet may he live awhile; and, it may be,  

**As long as you or I**  
yet he must die.  

**ISABELLA**  
Under your sentence?  

**ANGELO**  
Yea.  

**ISABELLA**  
When, I beseech you? that in his reprieve,  
Longer or shorter, he may be so fitted  
That his soul sicken not.  

**ANGELO**  
Ha! fie, these filthy vices! It were as good  
To pardon him that hath from nature stolen  
A man already made, as to remit  
Their saucy sweetness that do coin heaven's image  
In stamps that are forbid: 'tis all as easy  
Falsely to take away a life true made  
As to put metal in restrained means  
To make a false one.  

**ISABELLA**  
'Tis set down so in heaven, but not in earth.  

**ANGELO**  
Say you so? then I shall pose you quickly.  
Which had you rather, that the most just law  
Now took your brother's life; or, to redeem him,  
Give up your body to such sweet uncleanness  
As she that he hath stain'd?  

**ISABELLA**  
Sir, believe this,  
I had rather give my body than my soul.  

**ANGELO**  
I talk not of your soul: our compell'd sins  
Stand more for number than for accompt.  

**ISABELLA**  
How say you?  

**ANGELO**  
Nay, I'll not warrant that; for I can speak  
Against the thing I say. Answer to this:  
I, now the voice of the recorded law,  
Pronounce a sentence on your brother's life:  
Might there not be a charity in sin  
To save this brother's life?  

**ISABELLA**  
Please you to do't,  
I'll take it as a peril to my soul,  
It is no sin at all, but charity.  

**ANGELO**  
Pleased you to do't at peril of your soul,  
Were equal poise of sin and charity.  

**ISABELLA**  
That I do beg his life, if it be sin,  
Heaven let me bear it! you granting of my suit,  
If that be sin, I'll make it my morn prayer  
To have it added to the faults of mine,  
And nothing of your answer.  

**ANGELO**  
Nay, but hear me.  
Your sense pursues not mine: either you are ignorant,  
Or seem so craftily; and that's not good.  

**ISABELLA**  
Let me be ignorant, and in nothing good,  
But graciously to know I am no better.  

**ANGELO**  
Thus wisdom wishes to appear most bright  
When it doth tax itself; as these black masks  
Proclaim an enshield beauty ten times louder  
Than beauty could, display'd. But mark me;  
To be received plain, I'll speak more gross:  
Your brother is to die.  

**ISABELLA**  
So.  

**ANGELO**  
And his offence is so, as it appears,  
Accountant to the law upon that pain.  

**ISABELLA**  
True.  

**ANGELO**  
Admit no other way to save his life,--  
As I subscribe not that, nor any other,  
But in the loss of question,--that you, his sister,  
Finding yourself desired of such a person,  
Whose credit with the judge, or own great place,  
Could fetch your brother from the manacles  
Of the all-building law; and that there were  
No earthly mean to save him, but that either  
You must lay down the treasures of your body  
To this supposed, or else to let him suffer;  
What would you do?  

**ISABELLA**  
As much for my poor brother as myself:  
That is, were I under the terms of death,  
The impression of keen whips I'ld wear as rubies,  
And strip myself to death, as to a bed  
That longing have been sick for, ere I'ld yield  
My body up to shame.  

**ANGELO**  
Then must your brother die.  

**ISABELLA**  
And 'twere the cheaper way:  
Better it were a brother died at once,  
Than that a sister, by redeeming him,  
Should die for ever.  

**ANGELO**  
Were not you then as cruel as the sentence  
That you have slander'd so?  

**ISABELLA**  
Ignomy in ransom and free pardon  
Are of two houses: lawful mercy  
Is nothing kin to foul redemption.  

**ANGELO**  
You seem'd of late to make the law a tyrant;  
And rather proved the sliding of your brother  
A merriment than a vice.  

**ISABELLA**  
O, pardon me, my lord; it oft falls out,  
To have what we would have, we speak not what we mean:  
I something do excuse the thing I hate,  
For his advantage that I dearly love.  

**ANGELO**  
We are all frail.  

**ISABELLA**  
Else let my brother die,  
If not a feodary, but only he  
Owe and succeed thy weakness.  

**ANGELO**  
Nay, women are frail too.  

**ISABELLA**  
Ay, as the glasses where they view themselves;  
Which are as easy broke as they make forms.  
Women! Help Heaven! men their creation mar  
In profiting by them. Nay, call us ten times frail;  
For we are soft as our complexions are,  
And credulous to false prints.  

**ANGELO**  
I think it well:  
And from this testimony of your own sex,--  
Since I suppose we are made to be no stronger  
Than faults may shake our frames,--let me be bold;  
I do arrest your words. Be that you are,  
That is, a woman; if you be more, you're none;  
If you be one, as you are well express'd  
By all external warrants, show it now,  
By putting on the destined livery.  

**ISABELLA**  
I have no tongue but one: gentle my lord,  
Let me entreat you speak the former language.  

**ANGELO**  
Plainly conceive, I love you.  

**ISABELLA**  
My brother did love Juliet,  
And you tell me that he shall die for it.  

**ANGELO**  
He shall not, Isabel, if you give me love.  

**ISABELLA**  
I know your virtue hath a licence in't,  
Which seems a little fouler than it is,  
To pluck on others.  

**ANGELO**  
Believe me, on mine honour,  
My words express my purpose.  

**ISABELLA**  
Ha! little honour to be much believed,  
And most pernicious purpose! Seeming, seeming!  
I will proclaim thee, Angelo; look for't:  
Sign me a present pardon for my brother,  
Or with an outstretch'd throat I'll tell the world aloud  
What man thou art.  

**ANGELO**  
Who will believe thee, Isabel?  
My unsoil'd name, the austereness of my life,  
My vouch against you, and my place i' the state,  
Will so your accusation overweigh,  
That you shall stifle in your own report  
And smell of calumny. I have begun,  
And now I give my sensual race the rein:  
Fit thy consent to my sharp appetite;  
Lay by all nicety and prolixious blushes,  
That banish what they sue for; redeem thy brother  
By yielding up thy body to my will;  
Or else he must not only die the death,  
But thy unkindness shall his death draw out  
To lingering sufferance. Answer me to-morrow,  
Or, by the affection that now guides me most,  
I'll prove a tyrant to him. As for you,  
Say what you can, my false o'erweighs your true.  

_Exit_

**ISABELLA**  
To whom should I complain? Did I tell this,  
Who would believe me? O perilous mouths,  
That bear in them one and the self-same tongue,  
Either of condemnation or approof;  
Bidding the law make court'sy to their will:  
Hooking both right and wrong to the appetite,  
To follow as it draws! I'll to my brother:  
Though he hath fallen by prompture of the blood,  
Yet hath he in him such a mind of honour.  
That, had he twenty heads to tender down  
On twenty bloody blocks, he'ld yield them up,  
Before his sister should her body stoop  
To such abhorr'd pollution.  
Then, Isabel, live chaste, and, brother, die:  
More than our brother is our chastity.  
I'll tell him yet of Angelo's request,  
And fit his mind to death, for his soul's rest.  

_Exit_

# ACT III

### SCENE I. A room in the prison.

_Enter DUKE VINCENTIO disguised as before, CLAUDIO, and Provost_

**DUKE VINCENTIO**  
So then you hope of pardon from Lord Angelo?  

**CLAUDIO**  
The miserable have no other medicine  
But only hope:  
I've hope to live, and am prepared to die.  

**DUKE VINCENTIO**  
Be absolute for death; either death or life  
Shall thereby be the sweeter. Reason thus with life:  
If I do lose thee, I do lose a thing  
That none but fools would keep: a breath thou art,  
Servile to all the skyey influences,  
That dost this habitation, where thou keep'st,  
Hourly afflict: merely, thou art death's fool;  
For him thou labour'st by thy flight to shun  
And yet runn'st toward him still. Thou art not noble;  
For all the accommodations that thou bear'st  
Are nursed by baseness. Thou'rt by no means valiant;  
For thou dost fear the soft and tender fork  
Of a poor worm. Thy best of rest is sleep,  
And that thou oft provokest; yet grossly fear'st  
Thy death, which is no more. Thou art not thyself;  
For thou exist'st on many a thousand grains  
That issue out of dust. Happy thou art not;  
For what thou hast not, still thou strivest to get,  
And what thou hast, forget'st. Thou art not certain;  
For thy complexion shifts to strange effects,  
After the moon. If thou art rich, thou'rt poor;  
For, like an ass whose back with ingots bows,  
Thou bear's thy heavy riches but a journey,  
And death unloads thee. Friend hast thou none;  
For thine own bowels, which do call thee sire,  
The mere effusion of thy proper loins,  
Do curse the gout, serpigo, and the rheum,  
For ending thee no sooner. Thou hast nor youth nor age,  
But, as it were, an after-dinner's sleep,  
Dreaming on both; for all thy blessed youth  
Becomes as aged, and doth beg the alms  
Of palsied eld; and when thou art old and rich,  
Thou hast neither heat, affection, limb, nor beauty,  
To make thy riches pleasant. What's yet in this  
That bears the name of life? Yet in this life  
Lie hid moe thousand deaths: yet death we fear,  
That makes these odds all even.  

**CLAUDIO**  
I humbly thank you.  
To sue to live, I find I seek to die;  
And, seeking death, find life: let it come on.  

**ISABELLA**  
_[Within]_  
What, ho! Peace here; grace and good company!  

**Provost**  
Who's there? come in: the wish deserves a welcome.  

**DUKE VINCENTIO**  
Dear sir, ere long I'll visit you again.  

**CLAUDIO**  
Most holy sir, I thank you.  

_Enter ISABELLA_

**ISABELLA**  
My business is a word or two with Claudio.  

**Provost**  
And very welcome. Look, signior, here's your sister.  

**DUKE VINCENTIO**  
Provost, a word with you.  

**Provost**  
As many as you please.  

**DUKE VINCENTIO**  
Bring me to hear them speak, where I may be concealed.  

_Exeunt DUKE VINCENTIO and Provost_

**CLAUDIO**  
Now, sister, what's the comfort?  

**ISABELLA**  
Why,  
As all comforts are; most good, most good indeed.  
Lord Angelo, having affairs to heaven,  
Intends you for his swift ambassador,  
Where you shall be an everlasting leiger:  
Therefore your best appointment make with speed;  
To-morrow you set on.  

**CLAUDIO**  
Is there no remedy?  

**ISABELLA**  
None, but such remedy as, to save a head,  
To cleave a heart in twain.  

**CLAUDIO**  
But is there any?  

**ISABELLA**  
Yes, brother, you may live:  
There is a devilish mercy in the judge,  
If you'll implore it, that will free your life,  
But fetter you till death.  

**CLAUDIO**  
Perpetual durance?  

**ISABELLA**  
Ay, just; perpetual durance, a restraint,  
Though all the world's vastidity you had,  
To a determined scope.  

**CLAUDIO**  
But in what nature?  

**ISABELLA**  
In such a one as, you consenting to't,  
Would bark your honour from that trunk you bear,  
And leave you naked.  

**CLAUDIO**  
Let me know the point.  

**ISABELLA**  
O, I do fear thee, Claudio; and I quake,  
Lest thou a feverous life shouldst entertain,  
And six or seven winters more respect  
Than a perpetual honour. Darest thou die?  
The sense of death is most in apprehension;  
And the poor beetle, that we tread upon,  
In corporal sufferance finds a pang as great  
As when a giant dies.  

**CLAUDIO**  
Why give you me this shame?  
Think you I can a resolution fetch  
From flowery tenderness? If I must die,  
I will encounter darkness as a bride,  
And hug it in mine arms.  

**ISABELLA**  
There spake my brother; there my father's grave  
Did utter forth a voice. Yes, thou must die:  
Thou art too noble to conserve a life  
In base appliances. This outward-sainted deputy,  
Whose settled visage and deliberate word  
Nips youth i' the head and follies doth emmew  
As falcon doth the fowl, is yet a devil  
His filth within being cast, he would appear  
A pond as deep as hell.  

**CLAUDIO**  
The prenzie Angelo!  

**ISABELLA**  
O, 'tis the cunning livery of hell,  
The damned'st body to invest and cover  
In prenzie guards! Dost thou think, Claudio?  
If I would yield him my virginity,  
Thou mightst be freed.  

**CLAUDIO**  
O heavens! it cannot be.  

**ISABELLA**  
Yes, he would give't thee, from this rank offence,  
So to offend him still. This night's the time  
That I should do what I abhor to name,  
Or else thou diest to-morrow.  

**CLAUDIO**  
Thou shalt not do't.  

**ISABELLA**  
O, were it but my life,  
I'ld throw it down for your deliverance  
As frankly as a pin.  

**CLAUDIO**  
Thanks, dear Isabel.  

**ISABELLA**  
Be ready, Claudio, for your death tomorrow.  

**CLAUDIO**  
Yes. Has he affections in him,  
That thus can make him bite the law by the nose,  
When he would force it? Sure, it is no sin,  
Or of the deadly seven, it is the least.  

**ISABELLA**  
Which is the least?  

**CLAUDIO**  
If it were damnable, he being so wise,  
Why would he for the momentary trick  
Be perdurably fined? O Isabel!  

**ISABELLA**  
What says my brother?  

**CLAUDIO**  
Death is a fearful thing.  

**ISABELLA**  
And shamed life a hateful.  

**CLAUDIO**  
Ay, but to die, and go we know not where;  
To lie in cold obstruction and to rot;  
This sensible warm motion to become  
A kneaded clod; and the delighted spirit  
To bathe in fiery floods, or to reside  
In thrilling region of thick-ribbed ice;  
To be imprison'd in the viewless winds,  
And blown with restless violence round about  
The pendent world; or to be worse than worst  
Of those that lawless and incertain thought  
Imagine howling: 'tis too horrible!  
The weariest and most loathed worldly life  
That age, ache, penury and imprisonment  
Can lay on nature is a paradise  
To what we fear of death.  

**ISABELLA**  
Alas, alas!  

**CLAUDIO**  
Sweet sister, let me live:  
What sin you do to save a brother's life,  
Nature dispenses with the deed so far  
That it becomes a virtue.  

**ISABELLA**  
O you beast!  
O faithless coward! O dishonest wretch!  
Wilt thou be made a man out of my vice?  
Is't not a kind of incest, to take life  
From thine own sister's shame? What should I think?  
Heaven shield my mother play'd my father fair!  
For such a warped slip of wilderness  
Ne'er issued from his blood. Take my defiance!  
Die, perish! Might but my bending down  
Reprieve thee from thy fate, it should proceed:  
I'll pray a thousand prayers for thy death,  
No word to save thee.  

**CLAUDIO**  
Nay, hear me, Isabel.  

**ISABELLA**  
O, fie, fie, fie!  
Thy sin's not accidental, but a trade.  
Mercy to thee would prove itself a bawd:  
'Tis best thou diest quickly.  

**CLAUDIO**  
O hear me, Isabella!  

_Re-enter DUKE VINCENTIO_

**DUKE VINCENTIO**  
Vouchsafe a word, young sister, but one word.  

**ISABELLA**  
What is your will?  

**DUKE VINCENTIO**  
Might you dispense with your leisure, I would by and  
by have some speech with you: the satisfaction I  
would require is likewise your own benefit.  

**ISABELLA**  
I have no superfluous leisure; my stay must be  
stolen out of other affairs; but I will attend you awhile.  

_Walks apart_

**DUKE VINCENTIO**  
Son, I have overheard what hath passed between you  
and your sister. Angelo had never the purpose to  
corrupt her; only he hath made an essay of her  
virtue to practise his judgment with the disposition  
of natures: she, having the truth of honour in her,  
hath made him that gracious denial which he is most  
glad to receive. I am confessor to Angelo, and I  
know this to be true; therefore prepare yourself to  
death: do not satisfy your resolution with hopes  
that are fallible: tomorrow you must die; go to  
your knees and make ready.  

**CLAUDIO**  
Let me ask my sister pardon. I am so out of love  
with life that I will sue to be rid of it.  

**DUKE VINCENTIO**  
Hold you there: farewell.  

_Exit CLAUDIO_

Provost, a word with you!  

_Re-enter Provost_

**Provost**  
What's your will, father  

**DUKE VINCENTIO**  
That now you are come, you will be gone. Leave me  
awhile with the maid: my mind promises with my  
habit no loss shall touch her by my company.  

**Provost**  
In good time.  

_Exit Provost. ISABELLA comes forward_

**DUKE VINCENTIO**  
The hand that hath made you fair hath made you good:  
the goodness that is cheap in beauty makes beauty  
brief in goodness; but grace, being the soul of  
your complexion, shall keep the body of it ever  
fair. The assault that Angelo hath made to you,  
fortune hath conveyed to my understanding; and, but  
that frailty hath examples for his falling, I should  
wonder at Angelo. How will you do to content this  
substitute, and to save your brother?  

**ISABELLA**  
I am now going to resolve him: I had rather my  
brother die by the law than my son should be  
unlawfully born. But, O, how much is the good duke  
deceived in Angelo! If ever he return and I can  
speak to him, I will open my lips in vain, or  
discover his government.  

**DUKE VINCENTIO**  
That shall not be much amiss: Yet, as the matter  
now stands, he will avoid your accusation; he made  
trial of you only. Therefore fasten your ear on my  
advisings: to the love I have in doing good a  
remedy presents itself. I do make myself believe  
that you may most uprighteously do a poor wronged  
lady a merited benefit; redeem your brother from  
the angry law; do no stain to your own gracious  
person; and much please the absent duke, if  
peradventure he shall ever return to have hearing of  
this business.  

**ISABELLA**  
Let me hear you speak farther. I have spirit to do  
anything that appears not foul in the truth of my spirit.  

**DUKE VINCENTIO**  
Virtue is bold, and goodness never fearful. Have  
you not heard speak of Mariana, the sister of  
Frederick the great soldier who miscarried at sea?  

**ISABELLA**  
I have heard of the lady, and good words went with her name.  

**DUKE VINCENTIO**  
She should this Angelo have married; was affianced  
to her by oath, and the nuptial appointed: between  
which time of the contract and limit of the  
solemnity, her brother Frederick was wrecked at sea,  
having in that perished vessel the dowry of his  
sister. But mark how heavily this befell to the  
poor gentlewoman: there she lost a noble and  
renowned brother, in his love toward her ever most  
kind and natural; with him, the portion and sinew of  
her fortune, her marriage-dowry; with both, her  
combinate husband, this well-seeming Angelo.  

**ISABELLA**  
Can this be so? did Angelo so leave her?  

**DUKE VINCENTIO**  
Left her in her tears, and dried not one of them  
with his comfort; swallowed his vows whole,  
pretending in her discoveries of dishonour: in few,  
bestowed her on her own lamentation, which she yet  
wears for his sake; and he, a marble to her tears,  
is washed with them, but relents not.  

**ISABELLA**  
What a merit were it in death to take this poor maid  
from the world! What corruption in this life, that  
it will let this man live! But how out of this can she avail?  

**DUKE VINCENTIO**  
It is a rupture that you may easily heal: and the  
cure of it not only saves your brother, but keeps  
you from dishonour in doing it.  

**ISABELLA**  
Show me how, good father.  

**DUKE VINCENTIO**  
This forenamed maid hath yet in her the continuance  
of her first affection: his unjust unkindness, that  
in all reason should have quenched her love, hath,  
like an impediment in the current, made it more  
violent and unruly. Go you to Angelo; answer his  
requiring with a plausible obedience; agree with  
his demands to the point; only refer yourself to  
this advantage, first, that your stay with him may  
not be long; that the time may have all shadow and  
silence in it; and the place answer to convenience.  
This being granted in course,--and now follows  
all,--we shall advise this wronged maid to stead up  
your appointment, go in your place; if the encounter  
acknowledge itself hereafter, it may compel him to  
her recompense: and here, by this, is your brother  
saved, your honour untainted, the poor Mariana  
advantaged, and the corrupt deputy scaled. The maid  
will I frame and make fit for his attempt. If you  
think well to carry this as you may, the doubleness  
of the benefit defends the deceit from reproof.  
What think you of it?  

**ISABELLA**  
The image of it gives me content already; and I  
trust it will grow to a most prosperous perfection.  

**DUKE VINCENTIO**  
It lies much in your holding up. Haste you speedily  
to Angelo: if for this night he entreat you to his  
bed, give him promise of satisfaction. I will  
presently to Saint Luke's: there, at the moated  
grange, resides this dejected Mariana. At that  
place call upon me; and dispatch with Angelo, that  
it may be quickly.  

**ISABELLA**  
I thank you for this comfort. Fare you well, good father.  

_Exeunt severally_

### SCENE II. The street before the prison.

_Enter, on one side, DUKE VINCENTIO disguised as before; on the other,
ELBOW, and Officers with POMPEY_

**ELBOW**  
Nay, if there be no remedy for it, but that you will  
needs buy and sell men and women like beasts, we  
shall have all the world drink brown and white bastard.  

**DUKE VINCENTIO**  
O heavens! what stuff is here  

**POMPEY**  
'Twas never merry world since, of two usuries, the  
merriest was put down, and the worser allowed by  
order of law a furred gown to keep him warm; and  
furred with fox and lamb-skins too, to signify, that  
craft, being richer than innocency, stands for the facing.  

**ELBOW**  
Come your way, sir. 'Bless you, good father friar.  

**DUKE VINCENTIO**  
And you, good brother father. What offence hath  
this man made you, sir?  

**ELBOW**  
Marry, sir, he hath offended the law: and, sir, we  
take him to be a thief too, sir; for we have found  
upon him, sir, a strange picklock, which we have  
sent to the deputy.  

**DUKE VINCENTIO**  
Fie, sirrah! a bawd, a wicked bawd!  
The evil that thou causest to be done,  
That is thy means to live. Do thou but think  
What 'tis to cram a maw or clothe a back  
From such a filthy vice: say to thyself,  
From their abominable and beastly touches  
I drink, I eat, array myself, and live.  
Canst thou believe thy living is a life,  
So stinkingly depending? Go mend, go mend.  

**POMPEY**  
Indeed, it does stink in some sort, sir; but yet,  
sir, I would prove--  

**DUKE VINCENTIO**  
Nay, if the devil have given thee proofs for sin,  
Thou wilt prove his. Take him to prison, officer:  
Correction and instruction must both work  
Ere this rude beast will profit.  

**ELBOW**  
He must before the deputy, sir; he has given him  
warning: the deputy cannot abide a whoremaster: if  
he be a whoremonger, and comes before him, he were  
as good go a mile on his errand.  

**DUKE VINCENTIO**  
That we were all, as some would seem to be,  
From our faults, as faults from seeming, free!  

**ELBOW**  
His neck will come to your waist,--a cord, sir.  

**POMPEY**  
I spy comfort; I cry bail. Here's a gentleman and a  
friend of mine.  

_Enter LUCIO_

**LUCIO**  
How now, noble Pompey! What, at the wheels of  
Caesar? art thou led in triumph? What, is there  
none of Pygmalion's images, newly made woman, to be  
had now, for putting the hand in the pocket and  
extracting it clutch'd? What reply, ha? What  
sayest thou to this tune, matter and method? Is't  
not drowned i' the last rain, ha? What sayest  
thou, Trot? Is the world as it was, man? Which is  
the way? Is it sad, and few words? or how? The  
trick of it?  

**DUKE VINCENTIO**  
Still thus, and thus; still worse!  

**LUCIO**  
How doth my dear morsel, thy mistress? Procures she  
still, ha?  

**POMPEY**  
Troth, sir, she hath eaten up all her beef, and she  
is herself in the tub.  

**LUCIO**  
Why, 'tis good; it is the right of it; it must be  
so: ever your fresh whore and your powdered bawd:  
an unshunned consequence; it must be so. Art going  
to prison, Pompey?  

**POMPEY**  
Yes, faith, sir.  

**LUCIO**  
Why, 'tis not amiss, Pompey. Farewell: go, say I  
sent thee thither. For debt, Pompey? or how?  

**ELBOW**  
For being a bawd, for being a bawd.  

**LUCIO**  
Well, then, imprison him: if imprisonment be the  
due of a bawd, why, 'tis his right: bawd is he  
doubtless, and of antiquity too; bawd-born.  
Farewell, good Pompey. Commend me to the prison,  
Pompey: you will turn good husband now, Pompey; you  
will keep the house.  

**POMPEY**  
I hope, sir, your good worship will be my bail.  

**LUCIO**  
No, indeed, will I not, Pompey; it is not the wear.  
I will pray, Pompey, to increase your bondage: If  
you take it not patiently, why, your mettle is the  
more. Adieu, trusty Pompey. 'Bless you, friar.  

**DUKE VINCENTIO**  
And you.  

**LUCIO**  
Does Bridget paint still, Pompey, ha?  

**ELBOW**  
Come your ways, sir; come.  

**POMPEY**  
You will not bail me, then, sir?  

**LUCIO**  
Then, Pompey, nor now. What news abroad, friar?  
what news?  

**ELBOW**  
Come your ways, sir; come.  

**LUCIO**  
Go to kennel, Pompey; go.  

_Exeunt ELBOW, POMPEY and Officers_

What news, friar, of the duke?  

**DUKE VINCENTIO**  
I know none. Can you tell me of any?  

**LUCIO**  
Some say he is with the Emperor of Russia; other  
some, he is in Rome: but where is he, think you?  

**DUKE VINCENTIO**  
I know not where; but wheresoever, I wish him well.  

**LUCIO**  
It was a mad fantastical trick of him to steal from  
the state, and usurp the beggary he was never born  
to. Lord Angelo dukes it well in his absence; he  
puts transgression to 't.  

**DUKE VINCENTIO**  
He does well in 't.  

**LUCIO**  
A little more lenity to lechery would do no harm in  
him: something too crabbed that way, friar.  

**DUKE VINCENTIO**  
It is too general a vice, and severity must cure it.  

**LUCIO**  
Yes, in good sooth, the vice is of a great kindred;  
it is well allied: but it is impossible to extirp  
it quite, friar, till eating and drinking be put  
down. They say this Angelo was not made by man and  
woman after this downright way of creation: is it  
true, think you?  

**DUKE VINCENTIO**  
How should he be made, then?  

**LUCIO**  
Some report a sea-maid spawned him; some, that he  
was begot between two stock-fishes. But it is  
certain that when he makes water his urine is  
congealed ice; that I know to be true: and he is a  
motion generative; that's infallible.  

**DUKE VINCENTIO**  
You are pleasant, sir, and speak apace.  

**LUCIO**  
Why, what a ruthless thing is this in him, for the  
rebellion of a codpiece to take away the life of a  
man! Would the duke that is absent have done this?  
Ere he would have hanged a man for the getting a  
hundred bastards, he would have paid for the nursing  
a thousand: he had some feeling of the sport: he  
knew the service, and that instructed him to mercy.  

**DUKE VINCENTIO**  
I never heard the absent duke much detected for  
women; he was not inclined that way.  

**LUCIO**  
O, sir, you are deceived.  

**DUKE VINCENTIO**  
'Tis not possible.  

**LUCIO**  
Who, not the duke? yes, your beggar of fifty; and  
his use was to put a ducat in her clack-dish: the  
duke had crotchets in him. He would be drunk too;  
that let me inform you.  

**DUKE VINCENTIO**  
You do him wrong, surely.  

**LUCIO**  
Sir, I was an inward of his. A shy fellow was the  
duke: and I believe I know the cause of his  
withdrawing.  

**DUKE VINCENTIO**  
What, I prithee, might be the cause?  

**LUCIO**  
No, pardon; 'tis a secret must be locked within the  
teeth and the lips: but this I can let you  
understand, the greater file of the subject held the  
duke to be wise.  

**DUKE VINCENTIO**  
Wise! why, no question but he was.  

**LUCIO**  
A very superficial, ignorant, unweighing fellow.  

**DUKE VINCENTIO**  
Either this is the envy in you, folly, or mistaking:  
the very stream of his life and the business he hath  
helmed must upon a warranted need give him a better  
proclamation. Let him be but testimonied in his own  
bringings-forth, and he shall appear to the  
envious a scholar, a statesman and a soldier.  
Therefore you speak unskilfully: or if your  
knowledge be more it is much darkened in your malice.  

**LUCIO**  
Sir, I know him, and I love him.  

**DUKE VINCENTIO**  
Love talks with better knowledge, and knowledge with  
dearer love.  

**LUCIO**  
Come, sir, I know what I know.  

**DUKE VINCENTIO**  
I can hardly believe that, since you know not what  
you speak. But, if ever the duke return, as our  
prayers are he may, let me desire you to make your  
answer before him. If it be honest you have spoke,  
you have courage to maintain it: I am bound to call  
upon you; and, I pray you, your name?  

**LUCIO**  
Sir, my name is Lucio; well known to the duke.  

**DUKE VINCENTIO**  
He shall know you better, sir, if I may live to  
report you.  

**LUCIO**  
I fear you not.  

**DUKE VINCENTIO**  
O, you hope the duke will return no more; or you  
imagine me too unhurtful an opposite. But indeed I  
can do you little harm; you'll forswear this again.  

**LUCIO**  
I'll be hanged first: thou art deceived in me,  
friar. But no more of this. Canst thou tell if  
Claudio die to-morrow or no?  

**DUKE VINCENTIO**  
Why should he die, sir?  

**LUCIO**  
Why? For filling a bottle with a tundish. I would  
the duke we talk of were returned again: the  
ungenitured agent will unpeople the province with  
continency; sparrows must not build in his  
house-eaves, because they are lecherous. The duke  
yet would have dark deeds darkly answered; he would  
never bring them to light: would he were returned!  
Marry, this Claudio is condemned for untrussing.  
Farewell, good friar: I prithee, pray for me. The  
duke, I say to thee again, would eat mutton on  
Fridays. He's not past it yet, and I say to thee,  
he would mouth with a beggar, though she smelt brown  
bread and garlic: say that I said so. Farewell.  

_Exit_

**DUKE VINCENTIO**  
No might nor greatness in mortality  
Can censure 'scape; back-wounding calumny  
The whitest virtue strikes. What king so strong  
Can tie the gall up in the slanderous tongue?  
But who comes here?  

_Enter ESCALUS, Provost, and Officers with MISTRESS OVERDONE_

**ESCALUS**  
Go; away with her to prison!  

**MISTRESS OVERDONE**  
Good my lord, be good to me; your honour is accounted  
a merciful man; good my lord.  

**ESCALUS**  
Double and treble admonition, and still forfeit in  
the same kind! This would make mercy swear and play  
the tyrant.  

**Provost**  
A bawd of eleven years' continuance, may it please  
your honour.  

**MISTRESS OVERDONE**  
My lord, this is one Lucio's information against me.  
Mistress Kate Keepdown was with child by him in the  
duke's time; he promised her marriage: his child  
is a year and a quarter old, come Philip and Jacob:  
I have kept it myself; and see how he goes about to abuse me!  

**ESCALUS**  
That fellow is a fellow of much licence: let him be  
called before us. Away with her to prison! Go to;  
no more words.  

_Exeunt Officers with MISTRESS OVERDONE_

Provost, my brother Angelo will not be altered;  
Claudio must die to-morrow: let him be furnished  
with divines, and have all charitable preparation.  
if my brother wrought by my pity, it should not be  
so with him.  

**Provost**  
So please you, this friar hath been with him, and  
advised him for the entertainment of death.  

**ESCALUS**  
Good even, good father.  

**DUKE VINCENTIO**  
Bliss and goodness on you!  

**ESCALUS**  
Of whence are you?  

**DUKE VINCENTIO**  
Not of this country, though my chance is now  
To use it for my time: I am a brother  
Of gracious order, late come from the See  
In special business from his holiness.  

**ESCALUS**  
What news abroad i' the world?  

**DUKE VINCENTIO**  
None, but that there is so great a fever on  
goodness, that the dissolution of it must cure it:  
novelty is only in request; and it is as dangerous  
to be aged in any kind of course, as it is virtuous  
to be constant in any undertaking. There is scarce  
truth enough alive to make societies secure; but  
security enough to make fellowships accurst: much  
upon this riddle runs the wisdom of the world. This  
news is old enough, yet it is every day's news. I  
pray you, sir, of what disposition was the duke?  

**ESCALUS**  
One that, above all other strifes, contended  
especially to know himself.  

**DUKE VINCENTIO**  
What pleasure was he given to?  

**ESCALUS**  
Rather rejoicing to see another merry, than merry at  
any thing which professed to make him rejoice: a  
gentleman of all temperance. But leave we him to  
his events, with a prayer they may prove prosperous;  
and let me desire to know how you find Claudio  
prepared. I am made to understand that you have  
lent him visitation.  

**DUKE VINCENTIO**  
He professes to have received no sinister measure  
from his judge, but most willingly humbles himself  
to the determination of justice: yet had he framed  
to himself, by the instruction of his frailty, many  
deceiving promises of life; which I by my good  
leisure have discredited to him, and now is he  
resolved to die.  

**ESCALUS**  
You have paid the heavens your function, and the  
prisoner the very debt of your calling. I have  
laboured for the poor gentleman to the extremest  
shore of my modesty: but my brother justice have I  
found so severe, that he hath forced me to tell him  
he is indeed Justice.  

**DUKE VINCENTIO**  
If his own life answer the straitness of his  
proceeding, it shall become him well; wherein if he  
chance to fail, he hath sentenced himself.  

**ESCALUS**  
I am going to visit the prisoner. Fare you well.  

**DUKE VINCENTIO**  
Peace be with you!  

_Exeunt ESCALUS and Provost_

He who the sword of heaven will bear  
Should be as holy as severe;  
Pattern in himself to know,  
Grace to stand, and virtue go;  
More nor less to others paying  
Than by self-offences weighing.  
Shame to him whose cruel striking  
Kills for faults of his own liking!  
Twice treble shame on Angelo,  
To weed my vice and let his grow!  
O, what may man within him hide,  
Though angel on the outward side!  
How may likeness made in crimes,  
Making practise on the times,  
To draw with idle spiders' strings  
Most ponderous and substantial things!  
Craft against vice I must apply:  
With Angelo to-night shall lie  
His old betrothed but despised;  
So disguise shall, by the disguised,  
Pay with falsehood false exacting,  
And perform an old contracting.  

_Exit_

# ACT IV

### SCENE I. The moated grange at ST. LUKE's.

_Enter MARIANA and a Boy_

_Boy sings_

Take, O, take those lips away,  
That so sweetly were forsworn;  
And those eyes, the break of day,  
Lights that do mislead the morn:  
But my kisses bring again, bring again;  
Seals of love, but sealed in vain, sealed in vain.  

**MARIANA**  
Break off thy song, and haste thee quick away:  
Here comes a man of comfort, whose advice  
Hath often still'd my brawling discontent.  

_Exit Boy_

_Enter DUKE VINCENTIO disguised as before_

I cry you mercy, sir; and well could wish  
You had not found me here so musical:  
Let me excuse me, and believe me so,  
My mirth it much displeased, but pleased my woe.  

**DUKE VINCENTIO**  
'Tis good; though music oft hath such a charm  
To make bad good, and good provoke to harm.  
I pray, you, tell me, hath any body inquired  
for me here to-day? much upon this time have  
I promised here to meet.  

**MARIANA**  
You have not been inquired after:  
I have sat here all day.  

_Enter ISABELLA_

**DUKE VINCENTIO**  
I do constantly believe you. The time is come even  
now. I shall crave your forbearance a little: may  
be I will call upon you anon, for some advantage to yourself.  

**MARIANA**  
I am always bound to you.  

_Exit_

**DUKE VINCENTIO**  
Very well met, and well come.  
What is the news from this good deputy?  

**ISABELLA**  
He hath a garden circummured with brick,  
Whose western side is with a vineyard back'd;  
And to that vineyard is a planched gate,  
That makes his opening with this bigger key:  
This other doth command a little door  
Which from the vineyard to the garden leads;  
There have I made my promise  
Upon the heavy middle of the night  
To call upon him.  

**DUKE VINCENTIO**  
But shall you on your knowledge find this way?  

**ISABELLA**  
I have ta'en a due and wary note upon't:  
With whispering and most guilty diligence,  
In action all of precept, he did show me  
The way twice o'er.  

**DUKE VINCENTIO**  
Are there no other tokens  
Between you 'greed concerning her observance?  

**ISABELLA**  
No, none, but only a repair i' the dark;  
And that I have possess'd him my most stay  
Can be but brief; for I have made him know  
I have a servant comes with me along,  
That stays upon me, whose persuasion is  
I come about my brother.  

**DUKE VINCENTIO**  
'Tis well borne up.  
I have not yet made known to Mariana  
A word of this. What, ho! within! come forth!  

_Re-enter MARIANA_

I pray you, be acquainted with this maid;  
She comes to do you good.  

**ISABELLA**  
I do desire the like.  

**DUKE VINCENTIO**  
Do you persuade yourself that I respect you?  

**MARIANA**  
Good friar, I know you do, and have found it.  

**DUKE VINCENTIO**  
Take, then, this your companion by the hand,  
Who hath a story ready for your ear.  
I shall attend your leisure: but make haste;  
The vaporous night approaches.  

**MARIANA**  
Will't please you walk aside?  

_Exeunt MARIANA and ISABELLA_

**DUKE VINCENTIO**  
O place and greatness! millions of false eyes  
Are stuck upon thee: volumes of report  
Run with these false and most contrarious quests  
Upon thy doings: thousand escapes of wit  
Make thee the father of their idle dreams  
And rack thee in their fancies.  

_Re-enter MARIANA and ISABELLA_

Welcome, how agreed?  

**ISABELLA**  
She'll take the enterprise upon her, father,  
If you advise it.  

**DUKE VINCENTIO**  
It is not my consent,  
But my entreaty too.  

**ISABELLA**  
Little have you to say  
When you depart from him, but, soft and low,  
'Remember now my brother.'  

**MARIANA**  
Fear me not.  

**DUKE VINCENTIO**  
Nor, gentle daughter, fear you not at all.  
He is your husband on a pre-contract:  
To bring you thus together, 'tis no sin,  
Sith that the justice of your title to him  
Doth flourish the deceit. Come, let us go:  
Our corn's to reap, for yet our tithe's to sow.  

_Exeunt_

### SCENE II. A room in the prison.

_Enter Provost and POMPEY_

**Provost**  
Come hither, sirrah. Can you cut off a man's head?  

**POMPEY**  
If the man be a bachelor, sir, I can; but if he be a  
married man, he's his wife's head, and I can never  
cut off a woman's head.  

**Provost**  
Come, sir, leave me your snatches, and yield me a  
direct answer. To-morrow morning are to die Claudio  
and Barnardine. Here is in our prison a common  
executioner, who in his office lacks a helper: if  
you will take it on you to assist him, it shall  
redeem you from your gyves; if not, you shall have  
your full time of imprisonment and your deliverance  
with an unpitied whipping, for you have been a  
notorious bawd.  

**POMPEY**  
Sir, I have been an unlawful bawd time out of mind;  
but yet I will be content to be a lawful hangman. I  
would be glad to receive some instruction from my  
fellow partner.  

**Provost**  
What, ho! Abhorson! Where's Abhorson, there?  

_Enter ABHORSON_

**ABHORSON**  
Do you call, sir?  

**Provost**  
Sirrah, here's a fellow will help you to-morrow in  
your execution. If you think it meet, compound with  
him by the year, and let him abide here with you; if  
not, use him for the present and dismiss him. He  
cannot plead his estimation with you; he hath been a bawd.  

**ABHORSON**  
A bawd, sir? fie upon him! he will discredit our mystery.  

**Provost**  
Go to, sir; you weigh equally; a feather will turn  
the scale.  

_Exit_

**POMPEY**  
Pray, sir, by your good favour,--for surely, sir, a  
good favour you have, but that you have a hanging  
look,--do you call, sir, your occupation a mystery?  

**ABHORSON**  
Ay, sir; a mystery  

**POMPEY**  
Painting, sir, I have heard say, is a mystery; and  
your whores, sir, being members of my occupation,  
using painting, do prove my occupation a mystery:  
but what mystery there should be in hanging, if I  
should be hanged, I cannot imagine.  

**ABHORSON**  
Sir, it is a mystery.  

**POMPEY**  
Proof?  

**ABHORSON**  
Every true man's apparel fits your thief: if it be  
too little for your thief, your true man thinks it  
big enough; if it be too big for your thief, your  
thief thinks it little enough: so every true man's  
apparel fits your thief.  

_Re-enter Provost_

**Provost**  
Are you agreed?  

**POMPEY**  
Sir, I will serve him; for I do find your hangman is  
a more penitent trade than your bawd; he doth  
oftener ask forgiveness.  

**Provost**  
You, sirrah, provide your block and your axe  
to-morrow four o'clock.  

**ABHORSON**  
Come on, bawd; I will instruct thee in my trade; follow.  

**POMPEY**  
I do desire to learn, sir: and I hope, if you have  
occasion to use me for your own turn, you shall find  
me yare; for truly, sir, for your kindness I owe you  
a good turn.  

**Provost**  
Call hither Barnardine and Claudio:  

_Exeunt POMPEY and ABHORSON_

The one has my pity; not a jot the other,  
Being a murderer, though he were my brother.  

_Enter CLAUDIO_

Look, here's the warrant, Claudio, for thy death:  
'Tis now dead midnight, and by eight to-morrow  
Thou must be made immortal. Where's Barnardine?  

**CLAUDIO**  
As fast lock'd up in sleep as guiltless labour  
When it lies starkly in the traveller's bones:  
He will not wake.  

**Provost**  
Who can do good on him?  
Well, go, prepare yourself.  

_Knocking within_

But, hark, what noise?  
Heaven give your spirits comfort!  

_Exit CLAUDIO_

By and by.  
I hope it is some pardon or reprieve  
For the most gentle Claudio.  

_Enter DUKE VINCENTIO disguised as before_

Welcome father.  

**DUKE VINCENTIO**  
The best and wholesomest spirts of the night  
Envelope you, good Provost! Who call'd here of late?  

**Provost**  
None, since the curfew rung.  

**DUKE VINCENTIO**  
Not Isabel?  

**Provost**  
No.  

**DUKE VINCENTIO**  
They will, then, ere't be long.  

**Provost**  
What comfort is for Claudio?  

**DUKE VINCENTIO**  
There's some in hope.  

**Provost**  
It is a bitter deputy.  

**DUKE VINCENTIO**  
Not so, not so; his life is parallel'd  
Even with the stroke and line of his great justice:  
He doth with holy abstinence subdue  
That in himself which he spurs on his power  
To qualify in others: were he meal'd with that  
Which he corrects, then were he tyrannous;  
But this being so, he's just.  

_Knocking within_

Now are they come.  

_Exit Provost_

This is a gentle provost: seldom when  
The steeled gaoler is the friend of men.  

_Knocking within_

How now! what noise? That spirit's possessed with haste  
That wounds the unsisting postern with these strokes.  

_Re-enter Provost_

**Provost**  
There he must stay until the officer  
Arise to let him in: he is call'd up.  

**DUKE VINCENTIO**  
Have you no countermand for Claudio yet,  
But he must die to-morrow?  

**Provost**  
None, sir, none.  

**DUKE VINCENTIO**  
As near the dawning, provost, as it is,  
You shall hear more ere morning.  

**Provost**  
Happily  
You something know; yet I believe there comes  
No countermand; no such example have we:  
Besides, upon the very siege of justice  
Lord Angelo hath to the public ear  
Profess'd the contrary.  

_Enter a Messenger_

This is his lordship's man.  

**DUKE VINCENTIO**  
And here comes Claudio's pardon.  

**Messenger**  
_[Giving a paper]_  
My lord hath sent you this note; and by me this  
further charge, that you swerve not from the  
smallest article of it, neither in time, matter, or  
other circumstance. Good morrow; for, as I take it,  
it is almost day.  

**Provost**  
I shall obey him.  

_Exit Messenger_

**DUKE VINCENTIO**  
_[Aside]_  
This is his pardon, purchased by such sin  
For which the pardoner himself is in.  
Hence hath offence his quick celerity,  
When it is born in high authority:  
When vice makes mercy, mercy's so extended,  
That for the fault's love is the offender friended.  
Now, sir, what news?  

**Provost**  
I told you. Lord Angelo, belike thinking me remiss  
in mine office, awakens me with this unwonted  
putting-on; methinks strangely, for he hath not used it before.  

**DUKE VINCENTIO**  
Pray you, let's hear.  

**Provost**  
_[Reads]_  
'Whatsoever you may hear to the contrary, let  
Claudio be executed by four of the clock; and in the  
afternoon Barnardine: for my better satisfaction,  
let me have Claudio's head sent me by five. Let  
this be duly performed; with a thought that more  
depends on it than we must yet deliver. Thus fail  
not to do your office, as you will answer it at your peril.'  
What say you to this, sir?  

**DUKE VINCENTIO**  
What is that Barnardine who is to be executed in the  
afternoon?  

**Provost**  
A Bohemian born, but here nursed un and bred; one  
that is a prisoner nine years old.  

**DUKE VINCENTIO**  
How came it that the absent duke had not either  
delivered him to his liberty or executed him? I  
have heard it was ever his manner to do so.  

**Provost**  
His friends still wrought reprieves for him: and,  
indeed, his fact, till now in the government of Lord  
Angelo, came not to an undoubtful proof.  

**DUKE VINCENTIO**  
It is now apparent?  

**Provost**  
Most manifest, and not denied by himself.  

**DUKE VINCENTIO**  
Hath he born himself penitently in prison? how  
seems he to be touched?  

**Provost**  
A man that apprehends death no more dreadfully but  
as a drunken sleep; careless, reckless, and fearless  
of what's past, present, or to come; insensible of  
mortality, and desperately mortal.  

**DUKE VINCENTIO**  
He wants advice.  

**Provost**  
He will hear none: he hath evermore had the liberty  
of the prison; give him leave to escape hence, he  
would not: drunk many times a day, if not many days  
entirely drunk. We have very oft awaked him, as if  
to carry him to execution, and showed him a seeming  
warrant for it: it hath not moved him at all.  

**DUKE VINCENTIO**  
More of him anon. There is written in your brow,  
provost, honesty and constancy: if I read it not  
truly, my ancient skill beguiles me; but, in the  
boldness of my cunning, I will lay myself in hazard.  
Claudio, whom here you have warrant to execute, is  
no greater forfeit to the law than Angelo who hath  
sentenced him. To make you understand this in a  
manifested effect, I crave but four days' respite;  
for the which you are to do me both a present and a  
dangerous courtesy.  

**Provost**  
Pray, sir, in what?  

**DUKE VINCENTIO**  
In the delaying death.  

**Provost**  
A lack, how may I do it, having the hour limited,  
and an express command, under penalty, to deliver  
his head in the view of Angelo? I may make my case  
as Claudio's, to cross this in the smallest.  

**DUKE VINCENTIO**  
By the vow of mine order I warrant you, if my  
instructions may be your guide. Let this Barnardine  
be this morning executed, and his head born to Angelo.  

**Provost**  
Angelo hath seen them both, and will discover the favour.  

**DUKE VINCENTIO**  
O, death's a great disguiser; and you may add to it.  
Shave the head, and tie the beard; and say it was  
the desire of the penitent to be so bared before his  
death: you know the course is common. If any thing  
fall to you upon this, more than thanks and good  
fortune, by the saint whom I profess, I will plead  
against it with my life.  

**Provost**  
Pardon me, good father; it is against my oath.  

**DUKE VINCENTIO**  
Were you sworn to the duke, or to the deputy?  

**Provost**  
To him, and to his substitutes.  

**DUKE VINCENTIO**  
You will think you have made no offence, if the duke  
avouch the justice of your dealing?  

**Provost**  
But what likelihood is in that?  

**DUKE VINCENTIO**  
Not a resemblance, but a certainty. Yet since I see  
you fearful, that neither my coat, integrity, nor  
persuasion can with ease attempt you, I will go  
further than I meant, to pluck all fears out of you.  
Look you, sir, here is the hand and seal of the  
duke: you know the character, I doubt not; and the  
signet is not strange to you.  

**Provost**  
I know them both.  

**DUKE VINCENTIO**  
The contents of this is the return of the duke: you  
shall anon over-read it at your pleasure; where you  
shall find, within these two days he will be here.  
This is a thing that Angelo knows not; for he this  
very day receives letters of strange tenor;  
perchance of the duke's death; perchance entering  
into some monastery; but, by chance, nothing of what  
is writ. Look, the unfolding star calls up the  
shepherd. Put not yourself into amazement how these  
things should be: all difficulties are but easy  
when they are known. Call your executioner, and off  
with Barnardine's head: I will give him a present  
shrift and advise him for a better place. Yet you  
are amazed; but this shall absolutely resolve you.  
Come away; it is almost clear dawn.  

_Exeunt_

### SCENE III. Another room in the same.

_Enter POMPEY_

**POMPEY**  
I am as well acquainted here as I was in our house  
of profession: one would think it were Mistress  
Overdone's own house, for here be many of her old  
customers. First, here's young Master Rash; he's in  
for a commodity of brown paper and old ginger,  
ninescore and seventeen pounds; of which he made  
five marks, ready money: marry, then ginger was not  
much in request, for the old women were all dead.  
Then is there here one Master Caper, at the suit of  
Master Three-pile the mercer, for some four suits of  
peach-coloured satin, which now peaches him a  
beggar. Then have we here young Dizy, and young  
Master Deep-vow, and Master Copperspur, and Master  
Starve-lackey the rapier and dagger man, and young  
Drop-heir that killed lusty Pudding, and Master  
Forthlight the tilter, and brave Master Shooty the  
great traveller, and wild Half-can that stabbed  
Pots, and, I think, forty more; all great doers in  
our trade, and are now 'for the Lord's sake.'  

_Enter ABHORSON_

**ABHORSON**  
Sirrah, bring Barnardine hither.  

**POMPEY**  
Master Barnardine! you must rise and be hanged.  
Master Barnardine!  

**ABHORSON**  
What, ho, Barnardine!  

**BARNARDINE**  
_[Within]_  
A pox o' your throats! Who makes that  
noise there? What are you?  

**POMPEY**  
Your friends, sir; the hangman. You must be so  
good, sir, to rise and be put to death.  

**BARNARDINE**  
_[Within]_  
Away, you rogue, away! I am sleepy.  

**ABHORSON**  
Tell him he must awake, and that quickly too.  

**POMPEY**  
Pray, Master Barnardine, awake till you are  
executed, and sleep afterwards.  

**ABHORSON**  
Go in to him, and fetch him out.  

**POMPEY**  
He is coming, sir, he is coming; I hear his straw rustle.  

**ABHORSON**  
Is the axe upon the block, sirrah?  

**POMPEY**  
Very ready, sir.  

_Enter BARNARDINE_

**BARNARDINE**  
How now, Abhorson? what's the news with you?  

**ABHORSON**  
Truly, sir, I would desire you to clap into your  
prayers; for, look you, the warrant's come.  

**BARNARDINE**  
You rogue, I have been drinking all night; I am not  
fitted for 't.  

**POMPEY**  
O, the better, sir; for he that drinks all night,  
and is hanged betimes in the morning, may sleep the  
sounder all the next day.  

**ABHORSON**  
Look you, sir; here comes your ghostly father: do  
we jest now, think you?  

_Enter DUKE VINCENTIO disguised as before_

**DUKE VINCENTIO**  
Sir, induced by my charity, and hearing how hastily  
you are to depart, I am come to advise you, comfort  
you and pray with you.  

**BARNARDINE**  
Friar, not I I have been drinking hard all night,  
and I will have more time to prepare me, or they  
shall beat out my brains with billets: I will not  
consent to die this day, that's certain.  

**DUKE VINCENTIO**  
O, sir, you must: and therefore I beseech you  
Look forward on the journey you shall go.  

**BARNARDINE**  
I swear I will not die to-day for any man's  
persuasion.  

**DUKE VINCENTIO**  
But hear you.  

**BARNARDINE**  
Not a word: if you have any thing to say to me,  
come to my ward; for thence will not I to-day.  

_Exit_

**DUKE VINCENTIO**  
Unfit to live or die: O gravel heart!  
After him, fellows; bring him to the block.  

_Exeunt ABHORSON and POMPEY_

_Re-enter Provost_

**Provost**  
Now, sir, how do you find the prisoner?  

**DUKE VINCENTIO**  
A creature unprepared, unmeet for death;  
And to transport him in the mind he is  
Were damnable.  

**Provost**  
Here in the prison, father,  
There died this morning of a cruel fever  
One Ragozine, a most notorious pirate,  
A man of Claudio's years; his beard and head  
Just of his colour. What if we do omit  
This reprobate till he were well inclined;  
And satisfy the deputy with the visage  
Of Ragozine, more like to Claudio?  

**DUKE VINCENTIO**  
O, 'tis an accident that heaven provides!  
Dispatch it presently; the hour draws on  
Prefix'd by Angelo: see this be done,  
And sent according to command; whiles I  
Persuade this rude wretch willingly to die.  

**Provost**  
This shall be done, good father, presently.  
But Barnardine must die this afternoon:  
And how shall we continue Claudio,  
To save me from the danger that might come  
If he were known alive?  

**DUKE VINCENTIO**  
Let this be done.  
Put them in secret holds, both Barnardine and Claudio:  
Ere twice the sun hath made his journal greeting  
To the under generation, you shall find  
Your safety manifested.  

**Provost**  
I am your free dependant.  

**DUKE VINCENTIO**  
Quick, dispatch, and send the head to Angelo.  

_Exit Provost_

Now will I write letters to Angelo,--  
The provost, he shall bear them, whose contents  
Shall witness to him I am near at home,  
And that, by great injunctions, I am bound  
To enter publicly: him I'll desire  
To meet me at the consecrated fount  
A league below the city; and from thence,  
By cold gradation and well-balanced form,  
We shall proceed with Angelo.  

_Re-enter Provost_

**Provost**  
Here is the head; I'll carry it myself.  

**DUKE VINCENTIO**  
Convenient is it. Make a swift return;  
For I would commune with you of such things  
That want no ear but yours.  

**Provost**  
I'll make all speed.  

_Exit_

**ISABELLA**  
_[Within]_  
Peace, ho, be here!  

**DUKE VINCENTIO**  
The tongue of Isabel. She's come to know  
If yet her brother's pardon be come hither:  
But I will keep her ignorant of her good,  
To make her heavenly comforts of despair,  
When it is least expected.  

_Enter ISABELLA_

**ISABELLA**  
Ho, by your leave!  

**DUKE VINCENTIO**  
Good morning to you, fair and gracious daughter.  

**ISABELLA**  
The better, given me by so holy a man.  
Hath yet the deputy sent my brother's pardon?  

**DUKE VINCENTIO**  
He hath released him, Isabel, from the world:  
His head is off and sent to Angelo.  

**ISABELLA**  
Nay, but it is not so.  

**DUKE VINCENTIO**  
It is no other: show your wisdom, daughter,  
In your close patience.  

**ISABELLA**  
O, I will to him and pluck out his eyes!  

**DUKE VINCENTIO**  
You shall not be admitted to his sight.  

**ISABELLA**  
Unhappy Claudio! wretched Isabel!  
Injurious world! most damned Angelo!  

**DUKE VINCENTIO**  
This nor hurts him nor profits you a jot;  
Forbear it therefore; give your cause to heaven.  
Mark what I say, which you shall find  
By every syllable a faithful verity:  
The duke comes home to-morrow; nay, dry your eyes;  
One of our convent, and his confessor,  
Gives me this instance: already he hath carried  
Notice to Escalus and Angelo,  
Who do prepare to meet him at the gates,  
There to give up their power. If you can, pace your wisdom  
In that good path that I would wish it go,  
And you shall have your bosom on this wretch,  
Grace of the duke, revenges to your heart,  
And general honour.  

**ISABELLA**  
I am directed by you.  

**DUKE VINCENTIO**  
This letter, then, to Friar Peter give;  
'Tis that he sent me of the duke's return:  
Say, by this token, I desire his company  
At Mariana's house to-night. Her cause and yours  
I'll perfect him withal, and he shall bring you  
Before the duke, and to the head of Angelo  
Accuse him home and home. For my poor self,  
I am combined by a sacred vow  
And shall be absent. Wend you with this letter:  
Command these fretting waters from your eyes  
With a light heart; trust not my holy order,  
If I pervert your course. Who's here?  

_Enter LUCIO_

**LUCIO**  
Good even. Friar, where's the provost?  

**DUKE VINCENTIO**  
Not within, sir.  

**LUCIO**  
O pretty Isabella, I am pale at mine heart to see  
thine eyes so red: thou must be patient. I am fain  
to dine and sup with water and bran; I dare not for  
my head fill my belly; one fruitful meal would set  
me to 't. But they say the duke will be here  
to-morrow. By my troth, Isabel, I loved thy brother:  
if the old fantastical duke of dark corners had been  
at home, he had lived.  

_Exit ISABELLA_

**DUKE VINCENTIO**  
Sir, the duke is marvellous little beholding to your  
reports; but the best is, he lives not in them.  

**LUCIO**  
Friar, thou knowest not the duke so well as I do:  
he's a better woodman than thou takest him for.  

**DUKE VINCENTIO**  
Well, you'll answer this one day. Fare ye well.  

**LUCIO**  
Nay, tarry; I'll go along with thee  
I can tell thee pretty tales of the duke.  

**DUKE VINCENTIO**  
You have told me too many of him already, sir, if  
they be true; if not true, none were enough.  

**LUCIO**  
I was once before him for getting a wench with child.  

**DUKE VINCENTIO**  
Did you such a thing?  

**LUCIO**  
Yes, marry, did I but I was fain to forswear it;  
they would else have married me to the rotten medlar.  

**DUKE VINCENTIO**  
Sir, your company is fairer than honest. Rest you well.  

**LUCIO**  
By my troth, I'll go with thee to the lane's end:  
if bawdy talk offend you, we'll have very little of  
it. Nay, friar, I am a kind of burr; I shall stick.  

_Exeunt_

### SCENE IV. A room in ANGELO's house.

_Enter ANGELO and ESCALUS_

**ESCALUS**  
Every letter he hath writ hath disvouched other.  

**ANGELO**  
In most uneven and distracted manner. His actions  
show much like to madness: pray heaven his wisdom be  
not tainted! And why meet him at the gates, and  
redeliver our authorities there  

**ESCALUS**  
I guess not.  

**ANGELO**  
And why should we proclaim it in an hour before his  
entering, that if any crave redress of injustice,  
they should exhibit their petitions in the street?  

**ESCALUS**  
He shows his reason for that: to have a dispatch of  
complaints, and to deliver us from devices  
hereafter, which shall then have no power to stand  
against us.  

**ANGELO**  
Well, I beseech you, let it be proclaimed betimes  
i' the morn; I'll call you at your house: give  
notice to such men of sort and suit as are to meet  
him.  

**ESCALUS**  
I shall, sir. Fare you well.  

**ANGELO**  
Good night.  

_Exit ESCALUS_

This deed unshapes me quite, makes me unpregnant  
And dull to all proceedings. A deflower'd maid!  
And by an eminent body that enforced  
The law against it! But that her tender shame  
Will not proclaim against her maiden loss,  
How might she tongue me! Yet reason dares her no;  
For my authority bears of a credent bulk,  
That no particular scandal once can touch  
But it confounds the breather. He should have lived,  
Save that riotous youth, with dangerous sense,  
Might in the times to come have ta'en revenge,  
By so receiving a dishonour'd life  
With ransom of such shame. Would yet he had lived!  
A lack, when once our grace we have forgot,  
Nothing goes right: we would, and we would not.  

_Exit_

### SCENE V. Fields without the town.

_Enter DUKE VINCENTIO in his own habit, and FRIAR PETER_

**DUKE VINCENTIO**  
These letters at fit time deliver me  

_Giving letters_

The provost knows our purpose and our plot.  
The matter being afoot, keep your instruction,  
And hold you ever to our special drift;  
Though sometimes you do blench from this to that,  
As cause doth minister. Go call at Flavius' house,  
And tell him where I stay: give the like notice  
To Valentinus, Rowland, and to Crassus,  
And bid them bring the trumpets to the gate;  
But send me Flavius first.  

**FRIAR PETER**  
It shall be speeded well.  

_Exit_

_Enter VARRIUS_

**DUKE VINCENTIO**  
I thank thee, Varrius; thou hast made good haste:  
Come, we will walk. There's other of our friends  
Will greet us here anon, my gentle Varrius.  

_Exeunt_

### SCENE VI. Street near the city gate.

_Enter ISABELLA and MARIANA_

**ISABELLA**  
To speak so indirectly I am loath:  
I would say the truth; but to accuse him so,  
That is your part: yet I am advised to do it;  
He says, to veil full purpose.  

**MARIANA**  
Be ruled by him.  

**ISABELLA**  
Besides, he tells me that, if peradventure  
He speak against me on the adverse side,  
I should not think it strange; for 'tis a physic  
That's bitter to sweet end.  

**MARIANA**  
I would Friar Peter--  

**ISABELLA**  
O, peace! the friar is come.  

_Enter FRIAR PETER_

**FRIAR PETER**  
Come, I have found you out a stand most fit,  
Where you may have such vantage on the duke,  
He shall not pass you. Twice have the trumpets sounded;  
The generous and gravest citizens  
Have hent the gates, and very near upon  
The duke is entering: therefore, hence, away!  

_Exeunt_

# ACT V

### SCENE I. The city gate.

_MARIANA veiled, ISABELLA, and FRIAR PETER, at their stand. Enter DUKE
VINCENTIO, VARRIUS, Lords, ANGELO, ESCALUS, LUCIO, Provost, Officers, and
Citizens, at several doors_

**DUKE VINCENTIO**  
My very worthy cousin, fairly met!  
Our old and faithful friend, we are glad to see you.  

**ANGELO** **ESCALUS**  
Happy return be to your royal grace!  

**DUKE VINCENTIO**  
Many and hearty thankings to you both.  
We have made inquiry of you; and we hear  
Such goodness of your justice, that our soul  
Cannot but yield you forth to public thanks,  
Forerunning more requital.  

**ANGELO**  
You make my bonds still greater.  

**DUKE VINCENTIO**  
O, your desert speaks loud; and I should wrong it,  
To lock it in the wards of covert bosom,  
When it deserves, with characters of brass,  
A forted residence 'gainst the tooth of time  
And razure of oblivion. Give me your hand,  
And let the subject see, to make them know  
That outward courtesies would fain proclaim  
Favours that keep within. Come, Escalus,  
You must walk by us on our other hand;  
And good supporters are you.  

_FRIAR PETER and ISABELLA come forward_

**FRIAR PETER**  
Now is your time: speak loud and kneel before him.  

**ISABELLA**  
Justice, O royal duke! Vail your regard  
Upon a wrong'd, I would fain have said, a maid!  
O worthy prince, dishonour not your eye  
By throwing it on any other object  
Till you have heard me in my true complaint  
And given me justice, justice, justice, justice!  

**DUKE VINCENTIO**  
Relate your wrongs; in what? by whom? be brief.  
Here is Lord Angelo shall give you justice:  
Reveal yourself to him.  

**ISABELLA**  
O worthy duke,  
You bid me seek redemption of the devil:  
Hear me yourself; for that which I must speak  
Must either punish me, not being believed,  
Or wring redress from you. Hear me, O hear me, here!  

**ANGELO**  
My lord, her wits, I fear me, are not firm:  
She hath been a suitor to me for her brother  
Cut off by course of justice,--  

**ISABELLA**  
By course of justice!  

**ANGELO**  
And she will speak most bitterly and strange.  

**ISABELLA**  
Most strange, but yet most truly, will I speak:  
That Angelo's forsworn; is it not strange?  
That Angelo's a murderer; is 't not strange?  
That Angelo is an adulterous thief,  
An hypocrite, a virgin-violator;  
Is it not strange and strange?  

**DUKE VINCENTIO**  
Nay, it is ten times strange.  

**ISABELLA**  
It is not truer he is Angelo  
Than this is all as true as it is strange:  
Nay, it is ten times true; for truth is truth  
To the end of reckoning.  

**DUKE VINCENTIO**  
Away with her! Poor soul,  
She speaks this in the infirmity of sense.  

**ISABELLA**  
O prince, I conjure thee, as thou believest  
There is another comfort than this world,  
That thou neglect me not, with that opinion  
That I am touch'd with madness! Make not impossible  
That which but seems unlike: 'tis not impossible  
But one, the wicked'st caitiff on the ground,  
May seem as shy, as grave, as just, as absolute  
As Angelo; even so may Angelo,  
In all his dressings, characts, titles, forms,  
Be an arch-villain; believe it, royal prince:  
If he be less, he's nothing; but he's more,  
Had I more name for badness.  

**DUKE VINCENTIO**  
By mine honesty,  
If she be mad,--as I believe no other,--  
Her madness hath the oddest frame of sense,  
Such a dependency of thing on thing,  
As e'er I heard in madness.  

**ISABELLA**  
O gracious duke,  
Harp not on that, nor do not banish reason  
For inequality; but let your reason serve  
To make the truth appear where it seems hid,  
And hide the false seems true.  

**DUKE VINCENTIO**  
Many that are not mad  
Have, sure, more lack of reason. What would you say?  

**ISABELLA**  
I am the sister of one Claudio,  
Condemn'd upon the act of fornication  
To lose his head; condemn'd by Angelo:  
I, in probation of a sisterhood,  
Was sent to by my brother; one Lucio  
As then the messenger,--  

**LUCIO**  
That's I, an't like your grace:  
I came to her from Claudio, and desired her  
To try her gracious fortune with Lord Angelo  
For her poor brother's pardon.  

**ISABELLA**  
That's he indeed.  

**DUKE VINCENTIO**  
You were not bid to speak.  

**LUCIO**  
No, my good lord;  
Nor wish'd to hold my peace.  

**DUKE VINCENTIO**  
I wish you now, then;  
Pray you, take note of it: and when you have  
A business for yourself, pray heaven you then  
Be perfect.  

**LUCIO**  
I warrant your honour.  

**DUKE VINCENTIO**  
The warrants for yourself; take heed to't.  

**ISABELLA**  
This gentleman told somewhat of my tale,--  

**LUCIO**  
Right.  

**DUKE VINCENTIO**  
It may be right; but you are i' the wrong  
To speak before your time. Proceed.  

**ISABELLA**  
I went  
To this pernicious caitiff deputy,--  

**DUKE VINCENTIO**  
That's somewhat madly spoken.  

**ISABELLA**  
Pardon it;  
The phrase is to the matter.  

**DUKE VINCENTIO**  
Mended again. The matter; proceed.  

**ISABELLA**  
In brief, to set the needless process by,  
How I persuaded, how I pray'd, and kneel'd,  
How he refell'd me, and how I replied,--  
For this was of much length,--the vile conclusion  
I now begin with grief and shame to utter:  
He would not, but by gift of my chaste body  
To his concupiscible intemperate lust,  
Release my brother; and, after much debatement,  
My sisterly remorse confutes mine honour,  
And I did yield to him: but the next morn betimes,  
His purpose surfeiting, he sends a warrant  
For my poor brother's head.  

**DUKE VINCENTIO**  
This is most likely!  

**ISABELLA**  
O, that it were as like as it is true!  

**DUKE VINCENTIO**  
By heaven, fond wretch, thou knowist not what thou speak'st,  
Or else thou art suborn'd against his honour  
In hateful practise. First, his integrity  
Stands without blemish. Next, it imports no reason  
That with such vehemency he should pursue  
Faults proper to himself: if he had so offended,  
He would have weigh'd thy brother by himself  
And not have cut him off. Some one hath set you on:  
Confess the truth, and say by whose advice  
Thou camest here to complain.  

**ISABELLA**  
And is this all?  
Then, O you blessed ministers above,  
Keep me in patience, and with ripen'd time  
Unfold the evil which is here wrapt up  
In countenance! Heaven shield your grace from woe,  
As I, thus wrong'd, hence unbelieved go!  

**DUKE VINCENTIO**  
I know you'ld fain be gone. An officer!  
To prison with her! Shall we thus permit  
A blasting and a scandalous breath to fall  
On him so near us? This needs must be a practise.  
Who knew of Your intent and coming hither?  

**ISABELLA**  
One that I would were here, Friar Lodowick.  

**DUKE VINCENTIO**  
A ghostly father, belike. Who knows that Lodowick?  

**LUCIO**  
My lord, I know him; 'tis a meddling friar;  
I do not like the man: had he been lay, my lord  
For certain words he spake against your grace  
In your retirement, I had swinged him soundly.  

**DUKE VINCENTIO**  
Words against me? this is a good friar, belike!  
And to set on this wretched woman here  
Against our substitute! Let this friar be found.  

**LUCIO**  
But yesternight, my lord, she and that friar,  
I saw them at the prison: a saucy friar,  
A very scurvy fellow.  

**FRIAR PETER**  
Blessed be your royal grace!  
I have stood by, my lord, and I have heard  
Your royal ear abused. First, hath this woman  
Most wrongfully accused your substitute,  
Who is as free from touch or soil with her  
As she from one ungot.  

**DUKE VINCENTIO**  
We did believe no less.  
Know you that Friar Lodowick that she speaks of?  

**FRIAR PETER**  
I know him for a man divine and holy;  
Not scurvy, nor a temporary meddler,  
As he's reported by this gentleman;  
And, on my trust, a man that never yet  
Did, as he vouches, misreport your grace.  

**LUCIO**  
My lord, most villanously; believe it.  

**FRIAR PETER**  
Well, he in time may come to clear himself;  
But at this instant he is sick my lord,  
Of a strange fever. Upon his mere request,  
Being come to knowledge that there was complaint  
Intended 'gainst Lord Angelo, came I hither,  
To speak, as from his mouth, what he doth know  
Is true and false; and what he with his oath  
And all probation will make up full clear,  
Whensoever he's convented. First, for this woman.  
To justify this worthy nobleman,  
So vulgarly and personally accused,  
Her shall you hear disproved to her eyes,  
Till she herself confess it.  

**DUKE VINCENTIO**  
Good friar, let's hear it.  

_ISABELLA is carried off guarded; and MARIANA comes forward_

Do you not smile at this, Lord Angelo?  
O heaven, the vanity of wretched fools!  
Give us some seats. Come, cousin Angelo;  
In this I'll be impartial; be you judge  
Of your own cause. Is this the witness, friar?  
First, let her show her face, and after speak.  

**MARIANA**  
Pardon, my lord; I will not show my face  
Until my husband bid me.  

**DUKE VINCENTIO**  
What, are you married?  

**MARIANA**  
No, my lord.  

**DUKE VINCENTIO**  
Are you a maid?  

**MARIANA**  
No, my lord.  

**DUKE VINCENTIO**  
A widow, then?  

**MARIANA**  
Neither, my lord.  

**DUKE VINCENTIO**  
Why, you are nothing then: neither maid, widow, nor wife?  

**LUCIO**  
My lord, she may be a punk; for many of them are  
neither maid, widow, nor wife.  

**DUKE VINCENTIO**  
Silence that fellow: I would he had some cause  
To prattle for himself.  

**LUCIO**  
Well, my lord.  

**MARIANA**  
My lord; I do confess I ne'er was married;  
And I confess besides I am no maid:  
I have known my husband; yet my husband  
Knows not that ever he knew me.  

**LUCIO**  
He was drunk then, my lord: it can be no better.  

**DUKE VINCENTIO**  
For the benefit of silence, would thou wert so too!  

**LUCIO**  
Well, my lord.  

**DUKE VINCENTIO**  
This is no witness for Lord Angelo.  

**MARIANA**  
Now I come to't my lord  
She that accuses him of fornication,  
In self-same manner doth accuse my husband,  
And charges him my lord, with such a time  
When I'll depose I had him in mine arms  
With all the effect of love.  

**ANGELO**  
Charges she more than me?  

**MARIANA**  
Not that I know.  

**DUKE VINCENTIO**  
No? you say your husband.  

**MARIANA**  
Why, just, my lord, and that is Angelo,  
Who thinks he knows that he ne'er knew my body,  
But knows he thinks that he knows Isabel's.  

**ANGELO**  
This is a strange abuse. Let's see thy face.  

**MARIANA**  
My husband bids me; now I will unmask.  

_Unveiling_

This is that face, thou cruel Angelo,  
Which once thou sworest was worth the looking on;  
This is the hand which, with a vow'd contract,  
Was fast belock'd in thine; this is the body  
That took away the match from Isabel,  
And did supply thee at thy garden-house  
In her imagined person.  

**DUKE VINCENTIO**  
Know you this woman?  

**LUCIO**  
Carnally, she says.  

**DUKE VINCENTIO**  
Sirrah, no more!  

**LUCIO**  
Enough, my lord.  

**ANGELO**  
My lord, I must confess I know this woman:  
And five years since there was some speech of marriage  
Betwixt myself and her; which was broke off,  
Partly for that her promised proportions  
Came short of composition, but in chief  
For that her reputation was disvalued  
In levity: since which time of five years  
I never spake with her, saw her, nor heard from her,  
Upon my faith and honour.  

**MARIANA**  
Noble prince,  
As there comes light from heaven and words from breath,  
As there is sense in truth and truth in virtue,  
I am affianced this man's wife as strongly  
As words could make up vows: and, my good lord,  
But Tuesday night last gone in's garden-house  
He knew me as a wife. As this is true,  
Let me in safety raise me from my knees  
Or else for ever be confixed here,  
A marble monument!  

**ANGELO**  
I did but smile till now:  
Now, good my lord, give me the scope of justice  
My patience here is touch'd. I do perceive  
These poor informal women are no more  
But instruments of some more mightier member  
That sets them on: let me have way, my lord,  
To find this practise out.  

**DUKE VINCENTIO**  
Ay, with my heart  
And punish them to your height of pleasure.  
Thou foolish friar, and thou pernicious woman,  
Compact with her that's gone, think'st thou thy oaths,  
Though they would swear down each particular saint,  
Were testimonies against his worth and credit  
That's seal'd in approbation? You, Lord Escalus,  
Sit with my cousin; lend him your kind pains  
To find out this abuse, whence 'tis derived.  
There is another friar that set them on;  
Let him be sent for.  

**FRIAR PETER**  
Would he were here, my lord! for he indeed  
Hath set the women on to this complaint:  
Your provost knows the place where he abides  
And he may fetch him.  

**DUKE VINCENTIO**  
Go do it instantly.  

_Exit Provost_

And you, my noble and well-warranted cousin,  
Whom it concerns to hear this matter forth,  
Do with your injuries as seems you best,  
In any chastisement: I for a while will leave you;  
But stir not you till you have well determined  
Upon these slanderers.  

**ESCALUS**  
My lord, we'll do it throughly.  

_Exit DUKE_

Signior Lucio, did not you say you knew that  
Friar Lodowick to be a dishonest person?  

**LUCIO**  
'Cucullus non facit monachum:' honest in nothing  
but in his clothes; and one that hath spoke most  
villanous speeches of the duke.  

**ESCALUS**  
We shall entreat you to abide here till he come and  
enforce them against him: we shall find this friar a  
notable fellow.  

**LUCIO**  
As any in Vienna, on my word.  

**ESCALUS**  
Call that same Isabel here once again; I would speak with her.  

_Exit an Attendant_

Pray you, my lord, give me leave to question; you  
shall see how I'll handle her.  

**LUCIO**  
Not better than he, by her own report.  

**ESCALUS**  
Say you?  

**LUCIO**  
Marry, sir, I think, if you handled her privately,  
she would sooner confess: perchance, publicly,  
she'll be ashamed.  

**ESCALUS**  
I will go darkly to work with her.  

**LUCIO**  
That's the way; for women are light at midnight.  

_Re-enter Officers with ISABELLA; and Provost with the DUKE VINCENTIO in his
friar 's habit_

**ESCALUS**  
Come on, mistress: here's a gentlewoman denies all  
that you have said.  

**LUCIO**  
My lord, here comes the rascal I spoke of; here with  
the provost.  

**ESCALUS**  
In very good time: speak not you to him till we  
call upon you.  

**LUCIO**  
Mum.  

**ESCALUS**  
Come, sir: did you set these women on to slander  
Lord Angelo? they have confessed you did.  

**DUKE VINCENTIO**  
'Tis false.  

**ESCALUS**  
How! know you where you are?  

**DUKE VINCENTIO**  
Respect to your great place! and let the devil  
Be sometime honour'd for his burning throne!  
Where is the duke? 'tis he should hear me speak.  

**ESCALUS**  
The duke's in us; and we will hear you speak:  
Look you speak justly.  

**DUKE VINCENTIO**  
Boldly, at least. But, O, poor souls,  
Come you to seek the lamb here of the fox?  
Good night to your redress! Is the duke gone?  
Then is your cause gone too. The duke's unjust,  
Thus to retort your manifest appeal,  
And put your trial in the villain's mouth  
Which here you come to accuse.  

**LUCIO**  
This is the rascal; this is he I spoke of.  

**ESCALUS**  
Why, thou unreverend and unhallow'd friar,  
Is't not enough thou hast suborn'd these women  
To accuse this worthy man, but, in foul mouth  
And in the witness of his proper ear,  
To call him villain? and then to glance from him  
To the duke himself, to tax him with injustice?  
Take him hence; to the rack with him! We'll touse you  
Joint by joint, but we will know his purpose.  
What 'unjust'!  

**DUKE VINCENTIO**  
Be not so hot; the duke  
Dare no more stretch this finger of mine than he  
Dare rack his own: his subject am I not,  
Nor here provincial. My business in this state  
Made me a looker on here in Vienna,  
Where I have seen corruption boil and bubble  
Till it o'er-run the stew; laws for all faults,  
But faults so countenanced, that the strong statutes  
Stand like the forfeits in a barber's shop,  
As much in mock as mark.  

**ESCALUS**  
Slander to the state! Away with him to prison!  

**ANGELO**  
What can you vouch against him, Signior Lucio?  
Is this the man that you did tell us of?  

**LUCIO**  
'Tis he, my lord. Come hither, goodman baldpate:  
do you know me?  

**DUKE VINCENTIO**  
I remember you, sir, by the sound of your voice: I  
met you at the prison, in the absence of the duke.  

**LUCIO**  
O, did you so? And do you remember what you said of the duke?  

**DUKE VINCENTIO**  
Most notedly, sir.  

**LUCIO**  
Do you so, sir? And was the duke a fleshmonger, a  
fool, and a coward, as you then reported him to be?  

**DUKE VINCENTIO**  
You must, sir, change persons with me, ere you make  
that my report: you, indeed, spoke so of him; and  
much more, much worse.  

**LUCIO**  
O thou damnable fellow! Did not I pluck thee by the  
nose for thy speeches?  

**DUKE VINCENTIO**  
I protest I love the duke as I love myself.  

**ANGELO**  
Hark, how the villain would close now, after his  
treasonable abuses!  

**ESCALUS**  
Such a fellow is not to be talked withal. Away with  
him to prison! Where is the provost? Away with him  
to prison! lay bolts enough upon him: let him  
speak no more. Away with those giglots too, and  
with the other confederate companion!  

**DUKE VINCENTIO**  
_[To Provost]_  
Stay, sir; stay awhile.  

**ANGELO**  
What, resists he? Help him, Lucio.  

**LUCIO**  
Come, sir; come, sir; come, sir; foh, sir! Why, you  
bald-pated, lying rascal, you must be hooded, must  
you? Show your knave's visage, with a pox to you!  
show your sheep-biting face, and be hanged an hour!  
Will't not off?  

_Pulls off the friar 's hood, and discovers DUKE VINCENTIO_

**DUKE VINCENTIO**  
Thou art the first knave that e'er madest a duke.  
First, provost, let me bail these gentle three.  

_[To LUCIO]_  
Sneak not away, sir; for the friar and you  
Must have a word anon. Lay hold on him.  

**LUCIO**  
This may prove worse than hanging.  

**DUKE VINCENTIO**  
_[To ESCALUS]_  
What you have spoke I pardon: sit you down:  
We'll borrow place of him.  

_[To ANGELO]_  
Sir, by your leave.  
Hast thou or word, or wit, or impudence,  
That yet can do thee office? If thou hast,  
Rely upon it till my tale be heard,  
And hold no longer out.  

**ANGELO**  
O my dread lord,  
I should be guiltier than my guiltiness,  
To think I can be undiscernible,  
When I perceive your grace, like power divine,  
Hath look'd upon my passes. Then, good prince,  
No longer session hold upon my shame,  
But let my trial be mine own confession:  
Immediate sentence then and sequent death  
Is all the grace I beg.  

**DUKE VINCENTIO**  
Come hither, Mariana.  
Say, wast thou e'er contracted to this woman?  

**ANGELO**  
I was, my lord.  

**DUKE VINCENTIO**  
Go take her hence, and marry her instantly.  
Do you the office, friar; which consummate,  
Return him here again. Go with him, provost.  

_Exeunt ANGELO, MARIANA, FRIAR PETER and Provost_

**ESCALUS**  
My lord, I am more amazed at his dishonour  
Than at the strangeness of it.  

**DUKE VINCENTIO**  
Come hither, Isabel.  
Your friar is now your prince: as I was then  
Advertising and holy to your business,  
Not changing heart with habit, I am still  
Attorney'd at your service.  

**ISABELLA**  
O, give me pardon,  
That I, your vassal, have employ'd and pain'd  
Your unknown sovereignty!  

**DUKE VINCENTIO**  
You are pardon'd, Isabel:  
And now, dear maid, be you as free to us.  
Your brother's death, I know, sits at your heart;  
And you may marvel why I obscured myself,  
Labouring to save his life, and would not rather  
Make rash remonstrance of my hidden power  
Than let him so be lost. O most kind maid,  
It was the swift celerity of his death,  
Which I did think with slower foot came on,  
That brain'd my purpose. But, peace be with him!  
That life is better life, past fearing death,  
Than that which lives to fear: make it your comfort,  
So happy is your brother.  

**ISABELLA**  
I do, my lord.  

_Re-enter ANGELO, MARIANA, FRIAR PETER, and Provost_

**DUKE VINCENTIO**  
For this new-married man approaching here,  
Whose salt imagination yet hath wrong'd  
Your well defended honour, you must pardon  
For Mariana's sake: but as he adjudged your brother,--  
Being criminal, in double violation  
Of sacred chastity and of promise-breach  
Thereon dependent, for your brother's life,--  
The very mercy of the law cries out  
Most audible, even from his proper tongue,  
'An Angelo for Claudio, death for death!'  
Haste still pays haste, and leisure answers leisure;  
Like doth quit like, and MEASURE still FOR MEASURE.  
Then, Angelo, thy fault's thus manifested;  
Which, though thou wouldst deny, denies thee vantage.  
We do condemn thee to the very block  
Where Claudio stoop'd to death, and with like haste.  
Away with him!  

**MARIANA**  
O my most gracious lord,  
I hope you will not mock me with a husband.  

**DUKE VINCENTIO**  
It is your husband mock'd you with a husband.  
Consenting to the safeguard of your honour,  
I thought your marriage fit; else imputation,  
For that he knew you, might reproach your life  
And choke your good to come; for his possessions,  
Although by confiscation they are ours,  
We do instate and widow you withal,  
To buy you a better husband.  

**MARIANA**  
O my dear lord,  
I crave no other, nor no better man.  

**DUKE VINCENTIO**  
Never crave him; we are definitive.  

**MARIANA**  
Gentle my liege,--  

_Kneeling_

**DUKE VINCENTIO**  
You do but lose your labour.  
Away with him to death!  

_[To LUCIO]_  
Now, sir, to you.  

**MARIANA**  
O my good lord! Sweet Isabel, take my part;  
Lend me your knees, and all my life to come  
I'll lend you all my life to do you service.  

**DUKE VINCENTIO**  
Against all sense you do importune her:  
Should she kneel down in mercy of this fact,  
Her brother's ghost his paved bed would break,  
And take her hence in horror.  

**MARIANA**  
Isabel,  
Sweet Isabel, do yet but kneel by me;  
Hold up your hands, say nothing; I'll speak all.  
They say, best men are moulded out of faults;  
And, for the most, become much more the better  
For being a little bad: so may my husband.  
O Isabel, will you not lend a knee?  

**DUKE VINCENTIO**  
He dies for Claudio's death.  

**ISABELLA**  
Most bounteous sir,  

_Kneeling_

Look, if it please you, on this man condemn'd,  
As if my brother lived: I partly think  
A due sincerity govern'd his deeds,  
Till he did look on me: since it is so,  
Let him not die. My brother had but justice,  
In that he did the thing for which he died:  
For Angelo,  
His act did not o'ertake his bad intent,  
And must be buried but as an intent  
That perish'd by the way: thoughts are no subjects;  
Intents but merely thoughts.  

**MARIANA**  
Merely, my lord.  

**DUKE VINCENTIO**  
Your suit's unprofitable; stand up, I say.  
I have bethought me of another fault.  
Provost, how came it Claudio was beheaded  
At an unusual hour?  

**Provost**  
It was commanded so.  

**DUKE VINCENTIO**  
Had you a special warrant for the deed?  

**Provost**  
No, my good lord; it was by private message.  

**DUKE VINCENTIO**  
For which I do discharge you of your office:  
Give up your keys.  

**Provost**  
Pardon me, noble lord:  
I thought it was a fault, but knew it not;  
Yet did repent me, after more advice;  
For testimony whereof, one in the prison,  
That should by private order else have died,  
I have reserved alive.  

**DUKE VINCENTIO**  
What's he?  

**Provost**  
His name is Barnardine.  

**DUKE VINCENTIO**  
I would thou hadst done so by Claudio.  
Go fetch him hither; let me look upon him.  

_Exit Provost_

**ESCALUS**  
I am sorry, one so learned and so wise  
As you, Lord Angelo, have still appear'd,  
Should slip so grossly, both in the heat of blood.  
And lack of temper'd judgment afterward.  

**ANGELO**  
I am sorry that such sorrow I procure:  
And so deep sticks it in my penitent heart  
That I crave death more willingly than mercy;  
'Tis my deserving, and I do entreat it.  

_Re-enter Provost, with BARNARDINE, CLAUDIO muffled, and JULIET_

**DUKE VINCENTIO**  
Which is that Barnardine?  

**Provost**  
This, my lord.  

**DUKE VINCENTIO**  
There was a friar told me of this man.  
Sirrah, thou art said to have a stubborn soul.  
That apprehends no further than this world,  
And squarest thy life according. Thou'rt condemn'd:  
But, for those earthly faults, I quit them all;  
And pray thee take this mercy to provide  
For better times to come. Friar, advise him;  
I leave him to your hand. What muffled fellow's that?  

**Provost**  
This is another prisoner that I saved.  
Who should have died when Claudio lost his head;  
As like almost to Claudio as himself.  

_Unmuffles CLAUDIO_

**DUKE VINCENTIO**  
_[To ISABELLA]_  
If he be like your brother, for his sake  
Is he pardon'd; and, for your lovely sake,  
Give me your hand and say you will be mine.  
He is my brother too: but fitter time for that.  
By this Lord Angelo perceives he's safe;  
Methinks I see a quickening in his eye.  
Well, Angelo, your evil quits you well:  
Look that you love your wife; her worth worth yours.  
I find an apt remission in myself;  
And yet here's one in place I cannot pardon.  

_[To LUCIO]_  
You, sirrah, that knew me for a fool, a coward,  
One all of luxury, an ass, a madman;  
Wherein have I so deserved of you,  
That you extol me thus?  

**LUCIO**  
'Faith, my lord. I spoke it but according to the  
trick. If you will hang me for it, you may; but I  
had rather it would please you I might be whipt.  

**DUKE VINCENTIO**  
Whipt first, sir, and hanged after.  
Proclaim it, provost, round about the city.  
Is any woman wrong'd by this lewd fellow,  
As I have heard him swear himself there's one  
Whom he begot with child, let her appear,  
And he shall marry her: the nuptial finish'd,  
Let him be whipt and hang'd.  

**LUCIO**  
I beseech your highness, do not marry me to a whore.  
Your highness said even now, I made you a duke:  
good my lord, do not recompense me in making me a cuckold.  

**DUKE VINCENTIO**  
Upon mine honour, thou shalt marry her.  
Thy slanders I forgive; and therewithal  
Remit thy other forfeits. Take him to prison;  
And see our pleasure herein executed.  

**LUCIO**  
Marrying a punk, my lord, is pressing to death,  
whipping, and hanging.  

**DUKE VINCENTIO**  
Slandering a prince deserves it.  

_Exit Officers with LUCIO_

She, Claudio, that you wrong'd, look you restore.  
Joy to you, Mariana! Love her, Angelo:  
I have confess'd her and I know her virtue.  
Thanks, good friend Escalus, for thy much goodness:  
There's more behind that is more gratulate.  
Thanks, provost, for thy care and secrecy:  
We shill employ thee in a worthier place.  
Forgive him, Angelo, that brought you home  
The head of Ragozine for Claudio's:  
The offence pardons itself. Dear Isabel,  
I have a motion much imports your good;  
Whereto if you'll a willing ear incline,  
What's mine is yours and what is yours is mine.  
So, bring us to our palace; where we'll show  
What's yet behind, that's meet you all should know.  

_Exeunt_
